@@ -49,6 +49,7 @@ from numpy import *
 import graph_tool.all as gt
 import graph_tool.draw
 import random as prandom
+import subprocess
 
 figure()
 
@@ -57,6 +58,10 @@ try:
 except RuntimeError:
     pass
 
+def conv_png(f):
+    subprocess.check_output(['pdftocairo', "-png", "-singlefile", "-transp",
+                             "-r", "300", f])
+
 prandom.seed(42)
 np.random.seed(42)
 gt.seed_rng(42)
