@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph.hh"
@@ -66,6 +66,8 @@ enum vertex_attr_t {
     VERTEX_TEXT_POSITION,
     VERTEX_TEXT_ROTATION,
     VERTEX_TEXT_OFFSET,
+    VERTEX_TEXT_OUT_WIDTH,
+    VERTEX_TEXT_OUT_COLOR,
     VERTEX_FONT_FAMILY,
     VERTEX_FONT_SLANT,
     VERTEX_FONT_WEIGHT,
@@ -90,6 +92,8 @@ enum edge_attr_t {
     EDGE_TEXT_COLOR,
     EDGE_TEXT_DISTANCE,
     EDGE_TEXT_PARALLEL,
+    EDGE_TEXT_OUT_WIDTH,
+    EDGE_TEXT_OUT_COLOR,
     EDGE_FONT_FAMILY,
     EDGE_FONT_SLANT,
     EDGE_FONT_WEIGHT,
@@ -130,7 +134,7 @@ typedef pair<double, double> pos_t;
 typedef std::tuple<double, double, double, double> color_t;
 typedef gt_hash_map<int, boost::any> attrs_t;
 
-typedef boost::mpl::map43<
+typedef boost::mpl::map47<
     boost::mpl::pair<boost::mpl::int_<VERTEX_SHAPE>, vertex_shape_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_FILL_COLOR>, color_t>,
@@ -146,14 +150,16 @@ typedef boost::mpl::map43<
     boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_POSITION>, double>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_ROTATION>, double>,
-    boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_OFFSET>, vector<double> >,
+    boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_OFFSET>, vector<double>>,
+    boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_OUT_WIDTH>, double>,
+    boost::mpl::pair<boost::mpl::int_<VERTEX_TEXT_OUT_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_FONT_FAMILY>, string>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_FONT_SLANT>, int32_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_FONT_WEIGHT>, int32_t>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_FONT_SIZE>, double>,
     boost::mpl::pair<boost::mpl::int_<VERTEX_SURFACE>, boost::python::object>,
-    boost::mpl::pair<boost::mpl::int_<VERTEX_PIE_FRACTIONS>, vector<double> >,
-    boost::mpl::pair<boost::mpl::int_<VERTEX_PIE_COLORS>, vector<color_t> >,
+    boost::mpl::pair<boost::mpl::int_<VERTEX_PIE_FRACTIONS>, vector<double>>,
+    boost::mpl::pair<boost::mpl::int_<VERTEX_PIE_COLORS>, vector<color_t>>,
     boost::mpl::pair<boost::mpl::int_<EDGE_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_PENWIDTH>, double>,
     boost::mpl::pair<boost::mpl::int_<EDGE_START_MARKER>, edge_marker_t>,
@@ -161,19 +167,21 @@ typedef boost::mpl::map43<
     boost::mpl::pair<boost::mpl::int_<EDGE_END_MARKER>, edge_marker_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_MARKER_SIZE>, double>,
     boost::mpl::pair<boost::mpl::int_<EDGE_MID_MARKER_POSITION>, double>,
-    boost::mpl::pair<boost::mpl::int_<EDGE_CONTROL_POINTS>, vector<double> >,
-    boost::mpl::pair<boost::mpl::int_<EDGE_DASH_STYLE>, vector<double> >,
-    boost::mpl::pair<boost::mpl::int_<EDGE_GRADIENT>, vector<double> >,
+    boost::mpl::pair<boost::mpl::int_<EDGE_CONTROL_POINTS>, vector<double>>,
+    boost::mpl::pair<boost::mpl::int_<EDGE_DASH_STYLE>, vector<double>>,
+    boost::mpl::pair<boost::mpl::int_<EDGE_GRADIENT>, vector<double>>,
     boost::mpl::pair<boost::mpl::int_<EDGE_TEXT>, string>,
     boost::mpl::pair<boost::mpl::int_<EDGE_TEXT_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_TEXT_DISTANCE>, double>,
     boost::mpl::pair<boost::mpl::int_<EDGE_TEXT_PARALLEL>, uint8_t>,
+    boost::mpl::pair<boost::mpl::int_<EDGE_TEXT_OUT_WIDTH>, double>,
+    boost::mpl::pair<boost::mpl::int_<EDGE_TEXT_OUT_COLOR>, color_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_FONT_FAMILY>, string>,
     boost::mpl::pair<boost::mpl::int_<EDGE_FONT_SLANT>, int32_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_FONT_WEIGHT>, int32_t>,
     boost::mpl::pair<boost::mpl::int_<EDGE_FONT_SIZE>, double>,
     boost::mpl::pair<boost::mpl::int_<EDGE_SLOPPY>, uint8_t>,
-    boost::mpl::pair<boost::mpl::int_<EDGE_SEAMLESS>, uint8_t> >
+    boost::mpl::pair<boost::mpl::int_<EDGE_SEAMLESS>, uint8_t>>
         attr_types;
 
 namespace std
@@ -317,7 +325,7 @@ struct Converter
     struct specific_convert<string, T2,
                             typename std::enable_if
                             <boost::mpl::not_<
-                                 std::is_same<T2,boost::python::object> >::type::value>::type>
+                                 std::is_same<T2,boost::python::object>>::type::value>::type>
     {
         string operator()(const T2& v) const
         {
@@ -331,7 +339,7 @@ struct Converter
 
     // vectors
     template <class T1, class T2>
-    struct specific_convert<vector<T1>, vector<T2> >
+    struct specific_convert<vector<T1>, vector<T2>>
     {
         vector<T1> operator()(const vector<T2>& v) const
         {
@@ -345,7 +353,7 @@ struct Converter
 
     // color_t
     template <class T2>
-    struct specific_convert<color_t, vector<T2> >
+    struct specific_convert<color_t, vector<T2>>
     {
         specific_convert<double, T2> c;
         color_t operator()(const vector<T2>& cv) const
@@ -360,7 +368,7 @@ struct Converter
 
     // vector<color_t>
     template <class T2>
-    struct specific_convert<vector<color_t>, vector<T2> >
+    struct specific_convert<vector<color_t>, vector<T2>>
     {
         specific_convert<double, T2> c;
         vector<color_t> operator()(const vector<T2>& cv) const
@@ -384,9 +392,9 @@ struct Converter
     struct specific_convert<vertex_shape_t, T2,
                             typename std::enable_if
                             <boost::mpl::and_<typename boost::mpl::not_<
-                                                  std::is_same<T2,string> >::type,
+                                                  std::is_same<T2,string>>::type,
                                               typename boost::mpl::not_<
-                                                  std::is_same<T2,boost::python::object> >::type>::type::value>::type>
+                                                  std::is_same<T2,boost::python::object>>::type>::type::value>::type>
     {
         specific_convert<int, T2> c;
         vertex_shape_t operator()(const T2& v) const
@@ -400,9 +408,9 @@ struct Converter
     struct specific_convert<edge_marker_t, T2,
                             typename std::enable_if
                             <boost::mpl::and_<typename boost::mpl::not_<
-                                                  std::is_same<T2,string> >::type,
+                                                  std::is_same<T2,string>>::type,
                                               typename boost::mpl::not_<
-                                                  std::is_same<T2,boost::python::object> >::type>::type::value>::type>
+                                                  std::is_same<T2,boost::python::object>>::type>::type::value>::type>
     {
         specific_convert<int, T2> c;
         edge_marker_t operator()(const T2& v) const
@@ -870,8 +878,8 @@ public:
             {
                 if (!outline)
                 {
-                    vector<double> f = _attrs.template get<vector<double> >(VERTEX_PIE_FRACTIONS);
-                    vector<color_t> fcolors = _attrs.template get<vector<color_t> >(VERTEX_PIE_COLORS);
+                    vector<double> f = _attrs.template get<vector<double>>(VERTEX_PIE_FRACTIONS);
+                    vector<color_t> fcolors = _attrs.template get<vector<color_t>>(VERTEX_PIE_COLORS);
                     draw_pie(size / 2 + pw / 2, f, fcolors, cr);
                 }
                 else
@@ -976,7 +984,7 @@ public:
                 cr.set_font_size(get_user_dist(cr, _attrs.template get<double>(VERTEX_FONT_SIZE)));
                 text_pos = _attrs.template get<double>(VERTEX_TEXT_POSITION);
                 text_rotation = _attrs.template get<double>(VERTEX_TEXT_ROTATION);
-                text_offset = _attrs.template get<vector<double> >(VERTEX_TEXT_OFFSET);
+                text_offset = _attrs.template get<vector<double>>(VERTEX_TEXT_OFFSET);
                 text_offset.resize(2, 0.0);
 
                 cr.rotate(text_rotation);
@@ -1011,10 +1019,20 @@ public:
 
                     cr.translate(anchor.first, anchor.second);
                 }
+
+                cr.text_path(text);
+                color = _attrs.template get<color_t>(VERTEX_TEXT_OUT_COLOR);
+                cr.set_source_rgba(get<0>(color), get<1>(color), get<2>(color),
+                                   get<3>(color));
+                cr.set_line_width(_attrs.template get<double>(VERTEX_TEXT_OUT_WIDTH));
+                cr.stroke();
+
+                cr.begin_new_path();
                 color = _attrs.template get<color_t>(VERTEX_TEXT_COLOR);
                 cr.set_source_rgba(get<0>(color), get<1>(color), get<2>(color),
                                    get<3>(color));
                 cr.show_text(text);
+
                 cr.begin_new_path();
                 cr.restore();
             }
@@ -1049,14 +1067,33 @@ public:
         pos_t pos_begin, pos_end;
 
         vector<double> controls =
-            _attrs.template get<vector<double> >(EDGE_CONTROL_POINTS);
+            _attrs.template get<vector<double>>(EDGE_CONTROL_POINTS);
         vector<double> gradient =
-            _attrs.template get<vector<double> >(EDGE_GRADIENT);
+            _attrs.template get<vector<double>>(EDGE_GRADIENT);
         if (gradient.size() == 1)
         {
             auto e_color = _attrs.template get<color_t>(EDGE_COLOR);
             auto s_color = _s._attrs.template get<color_t>(VERTEX_FILL_COLOR);
             auto t_color = _t._attrs.template get<color_t>(VERTEX_FILL_COLOR);
+            auto get_pie_color =
+                [&](auto& v, auto& color)
+                {
+                    if (v._attrs.template get<vertex_shape_t>(VERTEX_SHAPE) == SHAPE_PIE)
+                    {
+                        vector<double> f = v._attrs.template get<vector<double>>(VERTEX_PIE_FRACTIONS);
+                        vector<color_t> fcolors = v._attrs.template get<vector<color_t>>(VERTEX_PIE_COLORS);
+                        assert(f.size() == fcolors.size());
+                        if (!f.empty())
+                        {
+                            auto iter = std::max_element(f.begin(), f.end());
+                            size_t j = (iter - f.begin()) % fcolors.size();
+                            color = fcolors[j];
+                        }
+                    }
+                };
+            get_pie_color(_s, s_color);
+            get_pie_color(_t, t_color);
+
             gradient.resize(10);
             gradient[0] = 0;
             gradient[1] = get<0>(s_color);
@@ -1366,10 +1403,18 @@ public:
                 cr.translate(text_dist, 0);
             }
 
+            color = _attrs.template get<color_t>(EDGE_TEXT_OUT_COLOR);
+            cr.set_source_rgba(get<0>(color), get<1>(color), get<2>(color),
+                               get<3>(color));
+            cr.set_line_width(_attrs.template get<double>(EDGE_TEXT_OUT_WIDTH));
+            cr.stroke();
+
+            cr.begin_new_path();
             color = _attrs.template get<color_t>(EDGE_TEXT_COLOR);
             cr.set_source_rgba(get<0>(color), get<1>(color), get<2>(color),
                                get<3>(color));
             cr.show_text(text);
+
             cr.begin_new_path();
             cr.restore();
         }
@@ -1456,7 +1501,7 @@ public:
                         vector<double>& controls, Cairo::Context& cr)
     {
         cr.move_to(pos_begin_c.first, pos_begin_c.second);
-        vector<double> dashes = _attrs.template get<vector<double> >(EDGE_DASH_STYLE);
+        vector<double> dashes = _attrs.template get<vector<double>>(EDGE_DASH_STYLE);
 
         if (dashes.size() > 2)
         {
@@ -1609,7 +1654,7 @@ void draw_edges(Graph& g, pair<EdgeIterator, EdgeIterator> e_range,
         VertexShape<vertex_t> ss(spos, AttrDict<vertex_t>(s, vattrs, vdefaults));
         VertexShape<vertex_t> ts(tpos, AttrDict<vertex_t>(t, vattrs, vdefaults));
 
-        EdgeShape<edge_t,VertexShape<vertex_t> > es(ss, ts,
+        EdgeShape<edge_t,VertexShape<vertex_t>> es(ss, ts,
                                                     AttrDict<edge_t>(*e, eattrs,
                                                                      edefaults));
         es.draw(cr, res);
@@ -1989,7 +2034,7 @@ struct do_put_parallel_splines
             }
             else if (get(l, *e) == 1)
             {
-                vector<pair<edge_t, bool> > pes;
+                vector<pair<edge_t, bool>> pes;
                 vertex_t s = source(*e, g);
                 typename graph_traits<Graph>::out_edge_iterator eo, eo_end;
                 for (tie(eo, eo_end) = out_edges(s, g); eo != eo_end; ++eo)
@@ -2089,7 +2134,7 @@ struct color_vector_from_list
     {
         converter::registry::push_back
             (&convertible, &construct,
-             boost::python::type_id<vector<color_t> >());
+             boost::python::type_id<vector<color_t>>());
     }
 
     static void* convertible(PyObject* obj_ptr)
@@ -2188,6 +2233,8 @@ BOOST_PYTHON_MODULE(libgraph_tool_draw)
         .value("text_position", VERTEX_TEXT_POSITION)
         .value("text_rotation", VERTEX_TEXT_ROTATION)
         .value("text_offset", VERTEX_TEXT_OFFSET)
+        .value("text_out_color", VERTEX_TEXT_OUT_COLOR)
+        .value("text_out_width", VERTEX_TEXT_OUT_WIDTH)
         .value("font_family", VERTEX_FONT_FAMILY)
         .value("font_slant", VERTEX_FONT_SLANT)
         .value("font_weight", VERTEX_FONT_WEIGHT)
@@ -2211,6 +2258,8 @@ BOOST_PYTHON_MODULE(libgraph_tool_draw)
         .value("text_color", EDGE_TEXT_COLOR)
         .value("text_distance", EDGE_TEXT_DISTANCE)
         .value("text_parallel", EDGE_TEXT_PARALLEL)
+        .value("text_out_color", EDGE_TEXT_OUT_COLOR)
+        .value("text_out_width", EDGE_TEXT_OUT_WIDTH)
         .value("font_family", EDGE_FONT_FAMILY)
         .value("font_slant", EDGE_FONT_SLANT)
         .value("font_weight", EDGE_FONT_WEIGHT)
