@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph.hh"
@@ -440,6 +440,13 @@ void copy_external_edge_property(const GraphInterface& src,
                                  boost::any prop_src,
                                  boost::any prop_tgt);
 
+bool compare_vertex_properties(const GraphInterface& gi,
+                               boost::any prop1,
+                               boost::any prop2);
+bool compare_edge_properties(const GraphInterface& gi,
+                             boost::any prop1,
+                             boost::any prop2);
+
 void export_python_interface();
 
 void export_openmp();
@@ -569,6 +576,8 @@ BOOST_PYTHON_MODULE(libgraph_tool_core)
     def("set_vertex_property", &set_vertex_property);
     def("set_edge_property", &set_edge_property);
     def("copy_external_edge_property", &copy_external_edge_property);
+    def("compare_vertex_properties", &compare_vertex_properties);
+    def("compare_edge_properties", &compare_edge_properties);
 
     class_<LibInfo>("mod_info")
         .add_property("name", &LibInfo::GetName)
