@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph_tool.hh"
@@ -76,7 +76,7 @@ void export_layered_overlap_blockmodel_state()
                           state_t;
 
                       double (state_t::*virtual_move)(size_t, size_t, size_t,
-                                                      entropy_args_t) =
+                                                      const entropy_args_t&) =
                           &state_t::virtual_move;
                       size_t (state_t::*sample_block)(size_t, double, double,
                                                       rng_t&)
@@ -88,7 +88,7 @@ void export_layered_overlap_blockmodel_state()
                                                      python::object) =
                           &state_t::move_vertices;
                       void (state_t::*couple_state)(LayeredBlockStateVirtualBase&,
-                                                    entropy_args_t) =
+                                                    const entropy_args_t&) =
                           &state_t::couple_state;
 
                       class_<state_t> c(name_demangle(typeid(state_t).name()).c_str(),
