@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph_tool.hh"
@@ -62,16 +62,8 @@ python::object mcmc_layered_overlap_sweep(python::object omcmc_state,
                      (omcmc_state,
                       [&](auto& s)
                       {
-                          if (s._parallel)
-                          {
-                              auto ret_ = mcmc_sweep_parallel(s, rng);
-                              ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
-                          }
-                          else
-                          {
-                              auto ret_ = mcmc_sweep(s, rng);
-                              ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
-                          }
+                          auto ret_ = mcmc_sweep(s, rng);
+                          ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
                       });
              },
              false);
