@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph.hh"
@@ -24,6 +24,7 @@
 #include "hash_map_wrap.hh"
 #include "coroutine.hh"
 #include "graph_python_interface.hh"
+#include "../generation/sampler.hh"
 
 #include <boost/graph/breadth_first_search.hpp>
 #include <boost/graph/dijkstra_shortest_paths_no_color_map.hpp>
@@ -549,8 +550,9 @@ void do_get_all_preds(GraphInterface& gi, boost::any adist, boost::any apred,
 }
 
 
-template <class Pred, class Yield>
-void get_all_shortest_paths(size_t s, size_t t, Pred pred, Yield& yield)
+template <class Graph, class Pred, class Yield>
+void get_all_shortest_paths(GraphInterface& gi, Graph& g, size_t s, size_t t,
+                            Pred pred, bool edges, Yield& yield)
 {
     vector<size_t> path;
     vector<pair<size_t, size_t>> stack = {{t, 0}};
@@ -560,10 +562,30 @@ void get_all_shortest_paths(size_t s, size_t t, Pred pred, Yield& yield)
         std::tie(v, i) = stack.back();
         if (v == s)
         {
-            path.clear();
-            for (auto iter = stack.rbegin(); iter != stack.rend(); ++iter)
-                path.push_back(iter->first);
-            yield(wrap_vector_owned<size_t>(path));
+            if (!edges)
+            {
+                path.clear();
+                for (auto iter = stack.rbegin(); iter != stack.rend(); ++iter)
+                    path.push_back(iter->first);
+                yield(wrap_vector_owned<size_t>(path));
+            }
+            else
+            {
+                auto gp = retrieve_graph_view<Graph>(gi, g);
+                boost::python::list opath;
+                auto s = graph_traits<Graph>::null_vertex();
+                for (auto iter = stack.rbegin(); iter != stack.rend(); ++iter)
+                {
+                    auto t = iter->first;
+                    if (s != graph_traits<Graph>::null_vertex())
+                    {
+                        auto e = edge(s, t, g).first;
+                        opath.append(PythonEdge<Graph>(gp, e));
+                    }
+                    s = t;
+                }
+                yield(opath);
+            }
         }
         if (pred[v].size() > i)
         {
@@ -579,14 +601,14 @@ void get_all_shortest_paths(size_t s, size_t t, Pred pred, Yield& yield)
 };
 
 python::object do_get_all_shortest_paths(GraphInterface& gi, size_t s, size_t t,
-                                         boost::any apred)
+                                         boost::any apred, bool edges)
 {
 #ifdef HAVE_BOOST_COROUTINE
     auto dispatch = [&](auto& yield)
         {
             run_action<>()
-                (gi, [&](auto&, auto pred)
-                     {get_all_shortest_paths(s, t, pred, yield);},
+                (gi, [&](auto& g, auto pred)
+                     {get_all_shortest_paths(gi, g, s, t, pred, edges, yield);},
                  vertex_scalar_vector_properties())(apred);
         };
     return python::object(CoroGenerator(dispatch));
@@ -595,6 +617,75 @@ python::object do_get_all_shortest_paths(GraphInterface& gi, size_t s, size_t t,
 #endif // HAVE_BOOST_COROUTINE
 }
 
+void get_weighted_succs(size_t t, boost::any apred, boost::any asucc,
+                        boost::any acount, boost::any avisited)
+{
+    typedef vprop_map_t<vector<int64_t>>::type pred_map_t;
+    typedef vprop_map_t<int64_t>::type count_map_t;
+    typedef vprop_map_t<uint8_t>::type visited_map_t;
+
+    pred_map_t pred = any_cast<pred_map_t>(apred);
+    pred_map_t succ = any_cast<pred_map_t>(asucc);
+    count_map_t count = any_cast<count_map_t>(acount);
+    visited_map_t visited = any_cast<visited_map_t>(avisited);
+
+    count[t] = 1;
+    visited[t] = true;
+
+    deque<size_t> queue = {t};
+    while (!queue.empty())
+    {
+        size_t v = queue.front();
+        queue.pop_front();
+        for (auto w : pred[v])
+        {
+            count[w] += count[v];
+            succ[w].push_back(v);
+
+            if (!visited[w])
+            {
+                visited[w] = true;
+                queue.push_back(w);
+            }
+        }
+    }
+};
+
+void get_random_shortest_path(size_t s, size_t t, boost::any asucc,
+                              boost::any acount, vector<size_t>& path,
+                              rng_t& rng)
+{
+    typedef vprop_map_t<vector<int64_t>>::type pred_map_t;
+    typedef vprop_map_t<int64_t>::type count_map_t;
+
+    pred_map_t succ = any_cast<pred_map_t>(asucc);
+    count_map_t count = any_cast<count_map_t>(acount);
+
+    vector<double> probs;
+    path.clear();
+
+    if (succ[s].empty())
+        return;
+
+    path.push_back(s);
+    size_t v = s;
+    while (v != t)
+    {
+        if (succ[v].size() == 1)
+        {
+            v = succ[v].front();
+        }
+        else
+        {
+            probs.clear();
+            for (auto w : succ[v])
+                probs.push_back(count[w]);
+            Sampler<int64_t> next(succ[v], probs);
+            v = next.sample(rng);
+        }
+        path.push_back(v);
+    }
+};
 
 template <bool edges, class Graph, class Yield, class VMap>
 void get_all_paths(size_t s, size_t t, size_t cutoff, VMap visited,
@@ -691,4 +782,7 @@ void export_dists()
     python::def("get_all_preds", &do_get_all_preds);
     python::def("get_all_shortest_paths", &do_get_all_shortest_paths);
     python::def("get_all_paths", &do_get_all_paths);
+
+    python::def("get_weighted_succs", &get_weighted_succs);
+    python::def("get_random_shortest_path", &get_random_shortest_path);
 };
