@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph.hh"
@@ -43,8 +43,11 @@ struct do_random_matching
 
         vector<vertex_t> vlist;
         typename graph_traits<Graph>::vertex_iterator v, v_end;
-        for (tie(v, v_end) = vertices(g); v != v_end; ++v)
-            vlist.push_back(*v);
+        for (auto v : vertices_range(g))
+        {
+            vlist.push_back(v);
+            match[v] = numeric_limits<typename property_traits<MatchMap>::value_type>::max();
+        }
 
         unchecked_vector_property_map<uint8_t, VertexIndex>
             matched(vertex_index, num_vertices(g));
@@ -82,7 +85,8 @@ struct do_random_matching
             {
                 uniform_int_distribution<> sample(0, candidates.size() - 1);
                 size_t j = sample(rng);
-                match[candidates[j]] = true;
+                match[v] = target(candidates[j], g);
+                match[target(candidates[j], g)] = v;
                 matched[v] = true;
                 matched[target(candidates[j], g)] = true;
             }
@@ -103,7 +107,7 @@ void random_matching(GraphInterface& gi, boost::any weight, boost::any match,
     run_action<>()
         (gi, std::bind(do_random_matching(), std::placeholders::_1, gi.get_vertex_index(),
                        std::placeholders::_2, std::placeholders::_3, minimize, std::ref(rng)),
-         edge_props_t(), writable_edge_scalar_properties())(weight, match);
+         edge_props_t(), writable_vertex_scalar_properties())(weight, match);
 }
 
 void export_random_matching()
