@@ -1,18 +1,18 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 //
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 3
-// of the License, or (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include <boost/python.hpp>
@@ -65,6 +65,7 @@ void export_random_matching();
 void export_maximal_vertex_set();
 void export_vertex_similarity();
 void export_max_cliques();
+void export_matching();
 
 
 BOOST_PYTHON_MODULE(libgraph_tool_topology)
@@ -96,4 +97,5 @@ BOOST_PYTHON_MODULE(libgraph_tool_topology)
     export_maximal_vertex_set();
     export_vertex_similarity();
     export_max_cliques();
+    export_matching();
 }
