@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.centrality`` - Centrality measures
@@ -44,14 +44,11 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_centrality")
 
 from .. import _prop, ungroup_vector_property, Vector_size_t
 from .. topology import shortest_distance
-import sys
 import numpy
 import numpy.linalg
 
@@ -156,17 +153,9 @@ def pagerank(g, damping=0.85, pers=None, weight=None, prop=None, epsilon=1e-6,
        ...               output="polblogs_pr.pdf")
        <...>
 
-    .. testcode:: pagerank
-       :hide:
-
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=pr,
-                     vertex_size=gt.prop_to_size(pr, mi=5, ma=15),
-                     vorder=pr, vcmap=matplotlib.cm.gist_heat,
-                     output="polblogs_pr.png")
-
-
-    .. figure:: polblogs_pr.*
+    .. figure:: polblogs_pr.png
        :align: center
+       :width: 80%
 
        PageRank values of the a political blogs network of [adamic-polblogs]_.
 
@@ -185,17 +174,15 @@ def pagerank(g, damping=0.85, pers=None, weight=None, prop=None, epsilon=1e-6,
        ...               output="polblogs_pr_pers.pdf")
        <...>
 
-    .. testcode:: pagerank
-       :hide:
+    .. testcleanup:: pagerank
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=pr,
-                     vertex_size=gt.prop_to_size(pr, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=pr, output="polblogs_pr_pers.png")
+       conv_png("polblogs_pr.pdf")
+       conv_png("polblogs_pr_pers.pdf")
 
 
-    .. figure:: polblogs_pr_pers.*
+    .. figure:: polblogs_pr_pers.png
        :align: center
+       :width: 80%
 
        Personalized PageRank values of the a political blogs network of
        [adamic-polblogs]_, where vertices with very low degree are given
@@ -310,18 +297,13 @@ def betweenness(g, pivots=None, vprop=None, eprop=None, weight=None, norm=True):
        ...               vorder=vp, output="polblogs_betweenness.pdf")
        <...>
 
-    .. testcode:: betweenness
-       :hide:
+    .. testcleanup:: betweenness
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=vp,
-                     vertex_size=gt.prop_to_size(vp, mi=5, ma=15),
-                     edge_pen_width=gt.prop_to_size(ep, mi=0.5, ma=5),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=vp, output="polblogs_betweenness.png")
+       conv_png("polblogs_betweenness.pdf")
 
-
-    .. figure:: polblogs_betweenness.*
+    .. figure:: polblogs_betweenness.png
        :align: center
+       :width: 80%
 
        Betweenness values of the a political blogs network of [adamic-polblogs]_.
 
@@ -354,7 +336,11 @@ def betweenness(g, pivots=None, vprop=None, eprop=None, weight=None, norm=True):
     vpivots.a = pivots
     libgraph_tool_centrality.\
             get_betweenness(g._Graph__graph, vpivots, _prop("e", g, weight),
-                            _prop("e", g, eprop), _prop("v", g, vprop), norm)
+                            _prop("e", g, eprop), _prop("v", g, vprop))
+    if norm:
+        libgraph_tool_centrality.\
+            norm_betweenness(g._Graph__graph, vpivots, _prop("e", g, eprop),
+                             _prop("v", g, vprop))
     return vprop, eprop
 
 def closeness(g, weight=None, source=None, vprop=None, norm=True, harmonic=False):
@@ -442,17 +428,13 @@ def closeness(g, weight=None, source=None, vprop=None, norm=True, harmonic=False
        ...               vorder=c, output="polblogs_closeness.pdf")
        <...>
 
-    .. testcode:: closeness
-       :hide:
+    .. testcleanup:: closeness
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=c,
-                     vertex_size=gt.prop_to_size(c, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=c, output="polblogs_closeness.png")
+       conv_png("polblogs_closeness.pdf")
 
-
-    .. figure:: polblogs_closeness.*
+    .. figure:: polblogs_closeness.png
        :align: center
+       :width: 80%
 
        Closeness values of the a political blogs network of [adamic-polblogs]_.
 
@@ -533,7 +515,7 @@ def central_point_dominance(g, betweenness):
     >>> g = gt.GraphView(g, vfilt=gt.label_largest_component(g))
     >>> vp, ep = gt.betweenness(g)
     >>> print(gt.central_point_dominance(g, vp))
-    0.105683...
+    0.218286...
 
     References
     ----------
@@ -625,17 +607,13 @@ def eigenvector(g, weight=None, vprop=None, epsilon=1e-6, max_iter=None):
        ...               vorder=x, output="polblogs_eigenvector.pdf")
        <...>
 
-    .. testcode:: eigenvector
-       :hide:
+    .. testcleanup:: eigenvector
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=x,
-                     vertex_size=gt.prop_to_size(x, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=x, output="polblogs_eigenvector.png")
+       conv_png("polblogs_eigenvector.pdf")
 
-
-    .. figure:: polblogs_eigenvector.*
+    .. figure:: polblogs_eigenvector.png
        :align: center
+       :width: 80%
 
        Eigenvector values of the a political blogs network of
        [adamic-polblogs]_, with random weights attributed to the edges.
@@ -746,17 +724,13 @@ def katz(g, alpha=0.01, beta=None, weight=None, vprop=None, epsilon=1e-6,
        ...               vorder=x, output="polblogs_katz.pdf")
        <...>
 
-    .. testcode:: katz
-       :hide:
+    .. testcleanup:: katz
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=x,
-                     vertex_size=gt.prop_to_size(x, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=x, output="polblogs_katz.png")
+       conv_png("polblogs_katz.pdf")
 
-
-    .. figure:: polblogs_katz.*
+    .. figure:: polblogs_katz.png
        :align: center
+       :width: 80%
 
        Katz centrality values of the a political blogs network of
        [adamic-polblogs]_, with random weights attributed to the edges.
@@ -871,27 +845,21 @@ def hits(g, weight=None, xprop=None, yprop=None, epsilon=1e-6, max_iter=None):
        ...               vorder=y, output="polblogs_hits_hubs.pdf")
        <...>
 
-    .. testcode:: hits
-       :hide:
+    .. testcleanup:: hits
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=x,
-                     vertex_size=gt.prop_to_size(x, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=x, output="polblogs_hits_auths.png")
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=y,
-                     vertex_size=gt.prop_to_size(y, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=y, output="polblogs_hits_hubs.png")
+       conv_png("polblogs_hits_auths.pdf")
+       conv_png("polblogs_hits_hubs.pdf")
 
-
-    .. figure:: polblogs_hits_auths.*
+    .. figure:: polblogs_hits_auths.png
        :align: center
+       :width: 80%
 
        HITS authority values of the a political blogs network of
        [adamic-polblogs]_.
 
-    .. figure:: polblogs_hits_hubs.*
+    .. figure:: polblogs_hits_hubs.png
        :align: center
+       :width: 80%
 
        HITS hub values of the a political blogs network of [adamic-polblogs]_.
 
@@ -996,17 +964,13 @@ def eigentrust(g, trust_map, vprop=None, norm=False, epsilon=1e-6, max_iter=0,
        ...               vorder=t, output="polblogs_eigentrust.pdf")
        <...>
 
-    .. testcode:: eigentrust
-       :hide:
+    .. testcleanup:: eigentrust
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=t,
-                     vertex_size=gt.prop_to_size(t, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=t, output="polblogs_eigentrust.png")
+       conv_png("polblogs_eigentrust.pdf")
 
-
-    .. figure:: polblogs_eigentrust.*
+    .. figure:: polblogs_eigentrust.png
        :align: center
+       :width: 80%
 
        Eigentrust values of the a political blogs network of
        [adamic-polblogs]_, with random weights attributed to the edges.
@@ -1127,17 +1091,13 @@ def trust_transitivity(g, trust_map, source=None, target=None, vprop=None):
        ...               vorder=t, output="polblogs_trust_transitivity.pdf")
        <...>
 
-    .. testcode:: trust_transitivity
-       :hide:
+    .. testcleanup:: trust_transitivity
 
-       gt.graph_draw(g, pos=g.vp["pos"], vertex_fill_color=t,
-                     vertex_size=gt.prop_to_size(t, mi=5, ma=15),
-                     vcmap=matplotlib.cm.gist_heat,
-                     vorder=t, output="polblogs_trust_transitivity.png")
+       conv_png("polblogs_trust_transitivity.pdf")
 
-
-    .. figure:: polblogs_trust_transitivity.*
+    .. figure:: polblogs_trust_transitivity.png
        :align: center
+       :width: 80%
 
        Trust transitivity values from source vertex 42 of the a political blogs
        network of [adamic-polblogs]_, with random weights attributed to the
