@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.clustering`` - Clustering coefficients
@@ -41,20 +41,16 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_clustering as _gt")
 
-from .. import _degree, _prop, Graph, GraphView, PropertyMap, _get_rng
+from .. import _prop, Graph, GraphView, VertexPropertyMap, _get_rng
 from .. topology import isomorphism
 from .. generation import random_rewire
 from .. stats import vertex_hist
 
 from collections import defaultdict
 from numpy import *
-from numpy import random
-import sys
 
 __all__ = ["local_clustering", "global_clustering", "extended_clustering",
            "motifs", "motif_significance"]
@@ -415,7 +411,7 @@ def motifs(g, k, p=1.0, motif_list=None, return_maps=False):
         vertex_maps = [x[2] for x in list_hist]
         for i, vlist in enumerate(vertex_maps):
             sub = sub_list[i]
-            vertex_maps[i] = [PropertyMap(vm, sub, "v") for vm in vlist]
+            vertex_maps[i] = [VertexPropertyMap(vm, sub) for vm in vlist]
         return sub_list, hist, vertex_maps
     return sub_list, hist
 
