@@ -3,43 +3,25 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import os.path
 import tempfile
-if sys.version_info < (3,):
-    from urllib2 import urlopen, URLError
-    import shutil
-    class TemporaryDirectory(object):
-        def __init__(self, suffix="", prefix="", dir=None):
-            self.name = tempfile.mkdtemp(suffix, prefix, dir)
-
-        def __enter__(self):
-            return self.name
-
-        def __exit__(self, exc, value, tb):
-            shutil.rmtree(self.name)
-else:
-    from urllib.request import urlopen, URLError
-    from tempfile import TemporaryDirectory
+from urllib.request import urlopen, URLError
+from tempfile import TemporaryDirectory
 import tarfile
 import warnings
 import numpy
@@ -88,7 +70,7 @@ def load_koblenz_dir(dirname):
                         meta[v] = line.strip()
                         count += 1
                 except ValueError as e:
-                    warnings.warn("error automatically reading node metadata from file '%s': %s" % (file, str(e)))
+                    warnings.warn("error automatically reading node metadata from file '%s': %s" % (f, str(e)))
     return g
 
 def get_koblenz_network_data(name):
