@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.correlations`` - Correlations
@@ -39,8 +39,6 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_correlations")
 
@@ -277,11 +275,6 @@ def corr_hist(g, deg_source, deg_target, bins=[[0, 1], [0, 1]], weight=None,
        <...>
        >>> savefig("corr.svg")
 
-    .. testcode:: corr_hist
-       :hide:
-
-       savefig("corr.pdf")
-
     .. figure:: corr.*
         :align: center
 
@@ -374,11 +367,6 @@ def combined_corr_hist(g, deg1, deg2, bins=[[0, 1], [0, 1]], float_count=True):
        <...>
        >>> savefig("combined_corr.svg")
 
-    .. testcode:: combined_corr_hist
-       :hide:
-
-       savefig("combined_corr.pdf")
-
     .. figure:: combined_corr.*
         :align: center
 
@@ -477,11 +465,6 @@ def avg_neighbor_corr(g, deg_source, deg_target, bins=[0, 1], weight=None):
        <...>
        >>> savefig("avg_corr.svg")
 
-    .. testcode:: avg_neighbor_corr
-       :hide:
-
-       savefig("avg_corr.pdf")
-
     .. figure:: avg_corr.*
         :align: center
 
@@ -567,11 +550,6 @@ def avg_combined_corr(g, deg1, deg2, bins=[0, 1]):
        <...>
        >>> savefig("combined_avg_corr.svg")
 
-    .. testcode:: avg_combined_corr
-       :hide:
-
-       savefig("combined_avg_corr.pdf")
-
     .. figure:: combined_avg_corr.*
         :align: center
 
