@@ -2,34 +2,27 @@
 # -*- coding: utf-8 -*-
 #
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 Some useful decorators
 """
 
-from __future__ import division, absolute_import, print_function
-
-__author__ = "Tiago de Paula Peixoto <tiago@skewed.de>"
-__copyright__ = "Copyright 2006-2019 Tiago de Paula Peixoto"
-__license__ = "GPL version 3 or above"
-
 import inspect
 import functools
-import sys
 import types
 
 ################################################################################
@@ -37,48 +30,7 @@ import types
 # Some useful function decorators which will be used
 ################################################################################
 
-# exec statement in python 2.7 and exec() function in 3.2 are mutually exclusive
-if sys.hexversion > 0x03000000:
-    def exec_function(source, filename, global_map):
-        exec(compile(source, filename, "exec"), global_map)
-else:
-    eval(compile("""\
-def exec_function(source, filename, global_map):
-    exec compile(source, filename, "exec") in global_map
-""","<exec_function>", "exec"))
-
-
-if sys.hexversion > 0x03000000:
-    _wraps = functools.wraps
-else:
-    def _wraps(func):
-        """This decorator works like the functools.wraps meta-decorator, but
-        also preserves the function's argument signature. This uses eval, and is
-        thus a bit of a hack, but there no better way I know of to do this."""
-        def decorate(f):
-            argspec = inspect.getargspec(func)
-            ___wrap_defaults = defaults = argspec[-1]
-            if defaults is not None:
-                def_string = ["___wrap_defaults[%d]" % d for
-                              d in range(len(defaults))]
-                def_names = argspec[0][-len(defaults):]
-            else:
-                def_string = None
-                def_names = None
-            args_call = inspect.formatargspec(argspec[0], defaults=def_names)
-            argspec = inspect.formatargspec(argspec[0], defaults=def_string)
-            argspec = argspec.lstrip("(").rstrip(")")
-            wf = "def %s(%s):\n    return f%s\n" % \
-                (func.__name__, argspec, args_call)
-            if def_string is not None:
-                for d in def_string:
-                    wf = wf.replace("'%s'" % d, "%s" % d)
-                for d in def_names:
-                    wf = wf.replace("'%s'" % d, "%s" % d)
-            exec_function(wf, __file__, locals())
-            return functools.wraps(func)(locals()[func.__name__])
-        return decorate
-
+_wraps = functools.wraps
 
 def _attrs(**kwds):
     """Decorator which adds arbitrary attributes to methods"""
@@ -97,7 +49,7 @@ def _limit_args(allowed_vals):
     def decorate(func):
         @_wraps(func)
         def wrap(*args, **kwargs):
-            arg_names = inspect.getargspec(func)[0]
+            arg_names = inspect.getfullargspec(func)[0]
             arguments = list(zip(arg_names, args))
             arguments += [(k, kwargs[k]) for k in list(kwargs.keys())]
             for a in arguments:
