@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.draw`` - Graph drawing and layout
@@ -66,18 +66,14 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-
-from .. import Graph, GraphView, _check_prop_vector, group_vector_property, \
-     ungroup_vector_property, infect_vertex_property, _prop, _get_rng
+from .. import Graph, GraphView, _check_prop_vector, _check_prop_scalar, \
+    group_vector_property, ungroup_vector_property, infect_vertex_property, \
+    _prop, _get_rng
 from .. topology import max_cardinality_matching, max_independent_vertex_set, \
-    label_components, pseudo_diameter, shortest_distance, make_maximal_planar, \
-    is_planar
-from .. stats import label_parallel_edges
+    label_components, shortest_distance, make_maximal_planar, is_planar
 from .. generation import predecessor_tree, condensation_graph
 import numpy.random
 from numpy import sqrt
-import sys
 
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_layout")
@@ -86,7 +82,7 @@ dl_import("from . import libgraph_tool_layout")
 __all__ = ["graph_draw", "graphviz_draw", "fruchterman_reingold_layout",
            "arf_layout", "sfdp_layout", "planar_layout", "random_layout",
            "radial_tree_layout", "cairo_draw", "prop_to_size",
-           "get_hierarchy_control_points", "default_cm"]
+           "get_hierarchy_control_points", "default_cm", "default_clrs"]
 
 
 def random_layout(g, shape=None, pos=None, dim=2):
@@ -185,13 +181,14 @@ def planar_layout(g, pos=None):
     >>> gt.graph_draw(g, pos=pos, output="lattice-planar.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, output="lattice-planar.png")
+       conv_png("lattice-planar.pdf")
 
-    .. figure:: lattice-planar.*
+
+    .. figure:: lattice-planar.png
         :align: center
+        :width: 60%
 
         Straight-line drawing of planar graph (a 2D square lattice).
 
@@ -278,15 +275,15 @@ def fruchterman_reingold_layout(g, weight=None, a=None, r=1., scale=None,
     >>> gt.graph_draw(g, pos=pos, output="graph-draw-fr.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, output="graph-draw-fr.png")
+       conv_png("graph-draw-fr.pdf")
 
-    .. figure:: graph-draw-fr.*
-        :align: center
+    .. figure:: graph-draw-fr.png
+       :align: center
+       :width: 60%
 
-        Fruchterman-Reingold layout of a Price network.
+       Fruchterman-Reingold layout of a Price network.
 
     References
     ----------
@@ -368,15 +365,15 @@ def arf_layout(g, weight=None, d=0.5, a=10, dt=0.001, epsilon=1e-6,
     >>> gt.graph_draw(g, pos=pos, output="graph-draw-arf.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, output="graph-draw-arf.png")
+       conv_png("graph-draw-arf.pdf")
 
-    .. figure:: graph-draw-arf.*
-        :align: center
+    .. figure:: graph-draw-arf.png
+       :align: center
+       :width: 60%
 
-        ARF layout of a Price network.
+       ARF layout of a Price network.
 
     References
     ----------
@@ -413,7 +410,7 @@ def _coarse_graph(g, vweight, eweight, mivs=False, groups=None):
             mivs = None
             m = max_cardinality_matching(GraphView(g, directed=False),
                                          heuristic=True, weight=eweight,
-                                         minimize=False)
+                                         minimize=False, edges=True)
             u = GraphView(g, efilt=m, directed=False)
             c = label_components(u)[0]
             c = g.own_property(c)
@@ -665,15 +662,15 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
     >>> gt.graph_draw(g, pos=pos, output="graph-draw-sfdp.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, output="graph-draw-sfdp.png")
+       conv_png("graph-draw-sfdp.pdf")
 
-    .. figure:: graph-draw-sfdp.*
-        :align: center
+    .. figure:: graph-draw-sfdp.png
+       :align: center
+       :width: 60%
 
-        SFDP layout of a Price network.
+       SFDP layout of a Price network.
 
     References
     ----------
@@ -685,6 +682,8 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
     if pos is None:
         pos = random_layout(g, dim=2)
     _check_prop_vector(pos, name="pos", floating=True)
+    if groups is not None:
+        _check_prop_scalar(groups, name="groups", floating=False)
 
     g_ = g
     g = GraphView(g, directed=False)
@@ -816,15 +815,15 @@ def radial_tree_layout(g, root, rel_order=None, rel_order_leaf=False,
     >>> gt.graph_draw(g, pos=pos, output="graph-draw-radial.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, output="graph-draw-radial.png")
+       conv_png("graph-draw-radial.pdf")
 
-    .. figure:: graph-draw-radial.*
-        :align: center
+    .. figure:: graph-draw-radial.png
+       :align: center
+       :width: 60%
 
-        Radial tree layout of a Price network.
+       Radial tree layout of a Price network.
 
     """
 
@@ -872,14 +871,16 @@ def prop_to_size(prop, mi=0, ma=5, log=False, power=0.5):
     return prop
 
 try:
-    from . cairo_draw import graph_draw, cairo_draw, get_hierarchy_control_points, default_cm
+    from . cairo_draw import graph_draw, cairo_draw, \
+        get_hierarchy_control_points, default_cm, default_clrs, draw_hierarchy
+    __all__ += ["draw_hierarchy"]
 except ImportError:
     pass
 
 try:
     from . cairo_draw import GraphWidget, GraphWindow, \
-        interactive_window, draw_hierarchy
-    __all__ += ["interactive_window", "GraphWidget", "GraphWindow", "draw_hierarchy"]
+        interactive_window
+    __all__ += ["interactive_window", "GraphWidget", "GraphWindow"]
 except ImportError:
     pass
 
