@@ -3,30 +3,27 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import division, absolute_import, print_function
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import numpy
 
-from .. import GraphView, PropertyMap, VertexPropertyMap, \
-    ungroup_vector_property, group_vector_property, infect_vertex_property, \
-    edge_endpoint_property, _prop
+from .. import GraphView, PropertyMap, ungroup_vector_property, \
+    group_vector_property, infect_vertex_property, edge_endpoint_property, _prop
 from .cairo_draw import *
-from .cairo_draw import _vdefaults, _edefaults
+from .cairo_draw import _edefaults
 from .. draw import sfdp_layout, random_layout, _avg_edge_distance, \
     coarse_graphs
 
@@ -367,6 +364,33 @@ class GraphWidget(Gtk.DrawingArea):
         self.is_rotating = False
         self.is_drag_gesture = False
 
+    def update(self, pos=None, vprops=None, eprops=None, vorder=None, eorder=None,
+               nodesfirst=None, display_props=None,
+               fit_view=True, bg_color=None, **kwargs):
+
+        props, kwargs = parse_props("vertex", kwargs)
+        vprops.update(props)
+        props, kwargs = parse_props("edge", kwargs)
+        eprops.update(props)
+
+        if pos is not None:
+            self.pos = pos
+        self.vprops.update(vprops)
+        self.eprops.update(eprops)
+        if vorder is not None:
+            self.vorder = vorder
+        if eorder is not None:
+            self.eorder = eorder
+        if nodesfirst is not None:
+            self.nodesfirst = nodesfirst
+
+        self.fit_view = fit_view
+
+        self.display_prop = self.g.vertex_index if display_props is None \
+                            else display_props
+        self.bg_color = bg_color if bg_color is not None else [1, 1, 1, 1]
+
+
     def cleanup(self):
         """Cleanup callbacks."""
         if gobject is None:
@@ -479,8 +503,7 @@ class GraphWidget(Gtk.DrawingArea):
 
         if (self.base is None or self.base_geometry[0] != geometry[0] or
             self.base_geometry[1] != geometry[1] or reset):
-            # self.base = cairo.ImageSurface(cairo.FORMAT_ARGB32,
-            #                                *geometry)
+
             w = self.get_window()
             if w is None:
                 return False
@@ -740,30 +763,37 @@ class GraphWidget(Gtk.DrawingArea):
         if g is None:
             g = self.g
         pos = g.own_property(self.pos)
-        cr = self.get_window().cairo_create()
         if self.fit_view != False:
             try:
                 x, y, w, h = self.fit_view
                 zoom = min(geometry[0] / w, geometry[1] / h)
-                offset = (x * zoom, y * zoom)
             except TypeError:
-                pad = self.fit_view if self.fit_view != True else 0.95
-                offset, zoom = fit_to_view(g, pos, geometry,
-                                           self.vprops.get("size", 0),
-                                           self.vprops.get("pen_width", 0),
-                                           self.tmatrix.multiply(self.smatrix),
-                                           self.vprops.get("text", None),
-                                           self.vprops.get("font_family",
-                                                           _vdefaults["font_family"]),
-                                           self.vprops.get("font_size",
-                                                           _vdefaults["font_size"]),
-                                           pad,
-                                           cr)
+                pad = self.fit_view if self.fit_view is not True else 0.9
+
+                M = self.tmatrix.multiply(self.smatrix)
+                pos_x, pos_y = ungroup_vector_property(pos, [0, 1])
+                P = np.zeros((2, len(pos_x.fa)))
+                P[0, :] = pos_x.fa
+                P[1, :] = pos_y.fa
+                T = np.zeros((2, 2))
+                O = np.zeros(2)
+                T[0, 0], T[1, 0], T[0, 1], T[1, 1], O[0], O[1] = M
+                P = np.dot(T, P)
+                P[0] += O[0]
+                P[1] += O[1]
+                pos_x.fa = P[0, :]
+                pos_y.fa = P[1, :]
+                pos = group_vector_property([pos_x, pos_y])
+
+                x, y, zoom = fit_to_view_ink(g, pos, geometry, self.vprops,
+                                             self.eprops, pad=pad)
         else:
-            offset, zoom = (0,0), 1
+            x, y, zoom = 0, 0, 1
+
         m = cairo.Matrix()
-        m.translate(offset[0] + ox, offset[1] + oy)
+        m.translate(ox, oy)
         m.scale(zoom, zoom)
+        m.translate(-x, -y)
         self.tmatrix = self.tmatrix.multiply(self.smatrix.multiply(m))
         self.smatrix = cairo.Matrix()
         if ink:
@@ -1187,9 +1217,9 @@ _window_list = []
 
 def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
                        eorder=None, nodesfirst=False, geometry=(500, 400),
-                       update_layout=True, sync=True, main=True, **kwargs):
-    r"""
-    Display an interactive GTK+ window containing the given graph.
+                       update_layout=True, sync=True, main=True,
+                       window=None, return_window=False, **kwargs):
+    r"""Display an interactive GTK+ window containing the given graph.
 
     Parameters
     ----------
@@ -1216,10 +1246,13 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
         Window geometry.
     update_layout : bool (optional, default: ``True``)
         If ``True``, the layout will be updated dynamically.
-    sync : bool (optional, default: ``True``)
-        If ``False``, run asynchronously. (Requires :mod:`IPython`)
     main : bool (optional, default: ``True``)
         If ``False``, the GTK+ main loop will not be called.
+    window : :class:`~graph_tool.draw.GraphWindow` (optional, default: ``None``)
+        If provided, specifies the window where the drawing will
+        occur. Otherwise a new one will be created.
+    return_window : bool (optional, default: ``False``)
+        If ``True``, the GTK+ window will be returned.
     **kwargs
         Any extra parameters are passed to :class:`~graph_tool.draw.GraphWindow`,
         :class:`~graph_tool.draw.GraphWidget` and :func:`~graph_tool.draw.cairo_draw`.
@@ -1239,28 +1272,35 @@ def interactive_window(g, pos=None, vprops=None, eprops=None, vorder=None,
     information.
 
     """
-    if pos is None:
-        if update_layout:
-            pos = random_layout(g, [1, 1])
-        else:
-            pos = sfdp_layout(g)
-    win = GraphWindow(g, pos, geometry, vprops, eprops, vorder, eorder,
-                      nodesfirst, update_layout, **kwargs)
-    win.show_all()
-    _window_list.append(win)
+    if window is None:
+        if pos is None:
+            if update_layout:
+                pos = random_layout(g, [1, 1])
+            else:
+                pos = sfdp_layout(g)
+        win = GraphWindow(g, pos, geometry, vprops, eprops, vorder, eorder,
+                          nodesfirst, update_layout, **kwargs)
+        win.show_all()
+        _window_list.append(win)
+    else:
+        win = window
+        win.graph.update(pos, vprops, eprops, vorder, eorder, nodesfirst,
+                         **kwargs)
+        win.graph.regenerate_surface(complete=True)
+        win.graph.queue_draw()
+
     if main:
-        if not sync:
-            # just a placeholder for a proper main loop integration with gtk3 when
-            # ipython implements it
-            import IPython.lib.inputhook
-            f = lambda: Gtk.main_iteration_do(False)
-            IPython.lib.inputhook.set_inputhook(f)
-        else:
-            def destroy_callback(*args, **kwargs):
-                global _window_list
-                for w in _window_list:
-                    w.destroy()
-                Gtk.main_quit()
-            win.connect("delete_event", destroy_callback)
-            Gtk.main()
+        def destroy_callback(*args, **kwargs):
+            global _window_list
+            for w in _window_list:
+                w.destroy()
+            Gtk.main_quit()
+        win.connect("delete_event", destroy_callback)
+        Gtk.main()
+    else:
+        while Gtk.events_pending():
+            Gtk.main_iteration()
+
+    if return_window:
+        return win
     return pos, win.graph.selected.copy()
