@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.dynamics`` - Dynamical processes
@@ -67,9 +67,8 @@ Contents
 
 """
 
-from __future__ import division, absolute_import, print_function
-
-from .. import _degree, _prop, Graph, GraphView, _get_rng, PropertyMap
+from .. import _degree, _prop, Graph, GraphView, _get_rng, PropertyMap, \
+    EdgePropertyMap, VertexPropertyMap, _check_prop_scalar
 from .. stats import label_self_loops
 import numpy
 import numpy.random
@@ -145,7 +144,7 @@ class DiscreteStateBase(object):
         return self._state.iterate_async(niter, _get_rng())
 
 class EpidemicStateBase(DiscreteStateBase):
-    def __init__(self, g, v0=None, s=None):
+    def __init__(self, g, constant_beta, make_state, params, v0=None, s=None):
         r"""Base state for epidemic dynamics. This class it not meant to be
         instantiated directly."""
 
@@ -158,37 +157,68 @@ class EpidemicStateBase(DiscreteStateBase):
                 v0 = g.vertex(v0, use_index=False)
             self.s[v0] = 1
 
+        beta = params["beta"]
+        weighted = isinstance(beta, EdgePropertyMap)
+        if weighted:
+            _check_prop_scalar(beta, "beta")
+            if beta.value_type() != "double":
+                if not constant_beta:
+                    raise ValueError("if constant_beta == False, the type of beta must be double")
+                beta = beta.copy("double")
+        params["beta"] = beta
+
+        for p in ["r", "epsilon", "gamma", "mu"]:
+            if p not in params:
+                continue
+            if not isinstance(params[p], VertexPropertyMap):
+                params[p] = g.new_vp("double", val=params[p])
+            _check_prop_scalar(params[p], p)
+            if params[p].value_type() != "double":
+                params[p] = params[p].copy("double")
+        self.params = params
+
+        self.make_state = lambda *args: make_state(*args, weighted, constant_beta)
+
+
 class SIState(EpidemicStateBase):
-    def __init__(self, g, beta=1., r=0, exposed=False, epsilon=.1, v0=None, s=None):
+    def __init__(self, g, beta=1., r=0, exposed=False, epsilon=.1, v0=None,
+                 s=None, constant_beta=True):
         r"""SI compartmental epidemic model.
 
         Parameters
         ----------
         g : :class:`~graph_tool.Graph`
            Graph to be used for the dynamics
-        beta : ``float`` (optional, default: ``1.``)
-           Transmission probability.
-        r : ``float`` (optional, default: ``0.``)
+        beta : ``float`` or :class:`~graph_tool.EdgePropertyMap` (optional, default: ``1.``)
+           Transmission probability. If an :class:`~graph_tool.EdgePropertyMap`
+           object is passed, it must contain the transmission probability for
+           every edge.
+        r : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``0.``)
            Spontaneous infection probability.
         exposed : ``boolean`` (optional, default: ``False``)
            If ``True``, an SEI model is simulated, with an additional "exposed"
            state.
-        epsilon : ``float`` (optional, default: ``.1``)
+        epsilon : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Susceptible to exposed transition probability. This only has an
            effect if ``exposed=True``.
         v0 : ``int`` or :class:`~graph_tool.Vertex` (optional, default: ``None``)
-           Initial infected vertex. If not provided, and if the global state is
+           Initial infectious vertex. If not provided, and if the global state is
            also not provided via paramter ``s``, a random vertex will be chosen.
         s : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
            Initial global state. If not provided, all vertices will be
            initialized to the susceptible state.
+        constant_beta : ``boolean`` (optional, default: ``True``)
+           If ``True``, and ``beta`` is an edge property map, it will be assumed
+           that the ``beta`` values do not change, such that the probability
+           values can be pre-computed for efficiency. If ``beta`` is a
+           ``float``, this option has no effect.
 
         Notes
         -----
 
         This implements an SI epidemic process [pastor-satorras-epidemic-2015]_,
         where nodes in the susceptible state (value 0) are infected by neighbours
-        in the infected state (value 1).
+        in the infectious state (value 1).
 
         If a node :math:`i` is updated at time :math:`t`, the transition
         probabilities from state :math:`s_i(t)` to state :math:`s_i(t+1)` are
@@ -197,7 +227,7 @@ class SIState(EpidemicStateBase):
         1. If :math:`s_i(t) = 0`, we have :math:`s_i(t+1) = 1` with probability
             .. math::
 
-               (1-r)\left(1-\prod_j(1-\beta)^{A_{ij}\delta_{s_j(t),1}}\right) + r,
+               (1-r_i)\left[1-\prod_j(1-\beta_{ij})^{A_{ij}\delta_{s_j(t),1}}\right] + r_i,
 
            otherwise :math:`s_i(t+1) = 0`.
 
@@ -206,7 +236,7 @@ class SIState(EpidemicStateBase):
 
         If the option ``exposed == True`` is given, then the states transit
         first from 0 to -1 (exposed) with probability given by 1. above, and
-        then finally from -1 to 1 with probability :math:`\epsilon`.
+        then finally from -1 to 1 with probability :math:`\epsilon_i`.
 
         Examples
         --------
@@ -231,20 +261,15 @@ class SIState(EpidemicStateBase):
            [...]
            >>> xlabel(r"Time")
            Text(...)
-           >>> ylabel(r"Infected nodes")
+           >>> ylabel(r"Infectious nodes")
            Text(...)
            >>> tight_layout()
-           >>> savefig("SI.pdf")
+           >>> savefig("SI.svg")
 
-        .. testcode:: SI
-           :hide:
-
-           savefig("SI.svg")
-
-        .. figure:: SI.*
+        .. figure:: SI.svg
            :align: center
 
-           Number of infected nodes vs. time for an SI dynamics.
+           Number of infectious nodes vs. time for an SI dynamics.
 
         References
         ----------
@@ -255,45 +280,52 @@ class SIState(EpidemicStateBase):
            :doi:`10.1103/RevModPhys.87.925`, :arxiv:`1408.2701`
 
         """
-        EpidemicStateBase.__init__(self, g, v0, s)
-        DiscreteStateBase.__init__(self, g,
+        EpidemicStateBase.__init__(self, g, constant_beta,
                                    lib_dynamics.make_SEI_state if exposed else lib_dynamics.make_SI_state,
-                                   dict(beta=beta, r=r, epsilon=epsilon), self.s)
+                                   dict(beta=beta, r=r, epsilon=epsilon),
+                                   v0, s)
+        DiscreteStateBase.__init__(self, g, self.make_state, self.params,
+                                   self.s)
 
 class SISState(DiscreteStateBase):
     def __init__(self, g, beta=1., gamma=.1, r=0, exposed=False, epsilon=.1,
-                 v0=None, s=None):
+                 v0=None, s=None, constant_beta=True):
         r"""SIS compartmental epidemic model.
 
         Parameters
         ----------
         g : :class:`~graph_tool.Graph`
            Graph to be used for the dynamics
-        beta : ``float`` (optional, default: ``1.``)
+        beta : ``float`` or :class:`~graph_tool.EdgePropertyMap` (optional, default: ``1.``)
            Transmission probability.
-        gamma : ``float`` (optional, default: ``.1``)
+        gamma : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Recovery probability.
-        r : ``float`` (optional, default: ``0.``)
+        r : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``0.``)
            Spontaneous infection probability.
         exposed : ``boolean`` (optional, default: ``False``)
            If ``True``, an SEIS model is simulated, with an additional "exposed"
            state.
-        epsilon : ``float`` (optional, default: ``.1``)
+        epsilon : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Susceptible to exposed transition probability. This only has an
            effect if ``exposed=True``.
         v0 : ``int`` or :class:`~graph_tool.Vertex` (optional, default: ``None``)
-           Initial infected vertex. If not provided, and if the global state is
+           Initial infectious vertex. If not provided, and if the global state is
            also not provided via paramter ``s``, a random vertex will be chosen.
         s : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
            Initial global state. If not provided, all vertices will be
            initialized to the susceptible state.
+        constant_beta : ``boolean`` (optional, default: ``True``)
+           If ``True``, and ``beta`` is an edge property map, it will be assumed
+           that the ``beta`` values do not change, such that the probability
+           values can be pre-computed for efficiency. If ``beta`` is a
+           ``float``, this option has no effect.
 
         Notes
         -----
 
         This implements an SIS epidemic process
         [pastor-satorras-epidemic-2015]_, where nodes in the susceptible state
-        (value 0) are infected by neighbours in the infected state (value 1),
+        (value 0) are infected by neighbours in the infectious state (value 1),
         which can then eventually recover to a susceptible state.
 
         If a node :math:`i` is updated at time :math:`t`, the transition
@@ -303,17 +335,17 @@ class SISState(DiscreteStateBase):
         1. If :math:`s_i(t) = 0`, we have :math:`s_i(t+1) = 1` with probability
             .. math::
 
-               (1-r)\left(1-\prod_j(1-\beta)^{A_{ij}\delta_{s_j(t),1}}\right) + r,
+               (1-r_i)\left[1-\prod_j(1-\beta_{ij})^{A_{ij}\delta_{s_j(t),1}}\right] + r_i,
 
            otherwise :math:`s_i(t+1) = 0`.
 
         2. If :math:`s_i(t) = 1`, we have :math:`s_i(t+1) = 0` with probability
-           :math:`\gamma`, or :math:`s_i(t+1) = 1` with probability
-           :math:`1-\gamma`.
+           :math:`\gamma_i`, or :math:`s_i(t+1) = 1` with probability
+           :math:`1-\gamma_i`.
 
         If the option ``exposed == True`` is given, then the states transit
         first from 0 to -1 (exposed) with probability given by 1. above, and
-        then finally from -1 to 1 with probability :math:`\epsilon`.
+        then finally from -1 to 1 with probability :math:`\epsilon_i`.
 
         Examples
         --------
@@ -338,20 +370,15 @@ class SISState(DiscreteStateBase):
            [...]
            >>> xlabel(r"Time")
            Text(...)
-           >>> ylabel(r"Infected nodes")
+           >>> ylabel(r"Infectious nodes")
            Text(...)
            >>> tight_layout()
-           >>> savefig("SI.pdf")
+           >>> savefig("SIS.svg")
 
-        .. testcode:: SIS
-           :hide:
-
-           savefig("SIS.svg")
-
-        .. figure:: SIS.*
+        .. figure:: SIS.svg
            :align: center
 
-           Number of infected nodes vs. time for an SIS dynamics.
+           Number of infectious nodes vs. time for an SIS dynamics.
 
         References
         ----------
@@ -362,45 +389,52 @@ class SISState(DiscreteStateBase):
            :doi:`10.1103/RevModPhys.87.925`, :arxiv:`1408.2701`
 
         """
-        EpidemicStateBase.__init__(self, g, v0, s)
-        DiscreteStateBase.__init__(self, g,
+        EpidemicStateBase.__init__(self, g, constant_beta,
                                    lib_dynamics.make_SEIS_state if exposed else lib_dynamics.make_SIS_state,
-                                   dict(beta=beta, gamma=gamma, r=r, epsilon=epsilon), self.s)
+                                   dict(beta=beta, gamma=gamma, r=r,
+                                        epsilon=epsilon),
+                                   v0, s)
+        DiscreteStateBase.__init__(self, g, self.make_state, self.params, self.s)
 
 class SIRState(DiscreteStateBase):
     def __init__(self, g, beta=1., gamma=.1, r=0, exposed=False, epsilon=.1,
-                 v0=None, s=None):
+                 v0=None, s=None, constant_beta=True):
         r"""SIR compartmental epidemic model.
 
         Parameters
         ----------
         g : :class:`~graph_tool.Graph`
            Graph to be used for the dynamics
-        beta : ``float`` (optional, default: ``1.``)
+        beta : ``float`` or :class:`~graph_tool.EdgePropertyMap` (optional, default: ``1.``)
            Transmission probability.
-        gamma : ``float`` (optional, default: ``.1``)
+        gamma : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Recovery probability.
-        r : ``float`` (optional, default: ``0.``)
+        r : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``0.``)
            Spontaneous infection probability.
         exposed : ``boolean`` (optional, default: ``False``)
            If ``True``, an SEIR model is simulated, with an additional "exposed"
            state.
-        epsilon : ``float`` (optional, default: ``.1``)
+        epsilon : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Susceptible to exposed transition probability. This only has an
            effect if ``exposed=True``.
         v0 : ``int`` or :class:`~graph_tool.Vertex` (optional, default: ``None``)
-           Initial infected vertex. If not provided, and if the global state is
+           Initial infectious vertex. If not provided, and if the global state is
            also not provided via paramter ``s``, a random vertex will be chosen.
         s : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
            Initial global state. If not provided, all vertices will be
            initialized to the susceptible state.
+        constant_beta : ``boolean`` (optional, default: ``True``)
+           If ``True``, and ``beta`` is an edge property map, it will be assumed
+           that the ``beta`` values do not change, such that the probability
+           values can be pre-computed for efficiency. If ``beta`` is a
+           ``float``, this option has no effect.
 
         Notes
         -----
 
         This implements an SIR epidemic process
         [pastor-satorras-epidemic-2015]_, where nodes in the susceptible state
-        (value 0) are infected by neighbours in the infected state (value 1),
+        (value 0) are infected by neighbours in the infectious state (value 1),
         which can then eventually recover to a recovered state (value 2).
 
         If a node :math:`i` is updated at time :math:`t`, the transition
@@ -410,17 +444,17 @@ class SIRState(DiscreteStateBase):
         1. If :math:`s_i(t) = 0`, we have :math:`s_i(t+1) = 1` with probability
             .. math::
 
-               (1-r)\left(1-\prod_j(1-\beta)^{A_{ij}\delta_{s_j(t),1}}\right) + r,
+               (1-r_i)\left[1-\prod_j(1-\beta_{ij})^{A_{ij}\delta_{s_j(t),1}}\right] + r_i,
 
            otherwise :math:`s_i(t+1) = 0`.
 
         2. If :math:`s_i(t) = 1`, we have :math:`s_i(t+1) = 2` with probability
-           :math:`\gamma`, or :math:`s_i(t+1) = 1` with probability
-           :math:`1-\gamma`.
+           :math:`\gamma_i`, or :math:`s_i(t+1) = 1` with probability
+           :math:`1-\gamma_i`.
 
         If the option ``exposed == True`` is given, then the states transit
         first from 0 to -1 (exposed) with probability given by 1. above, and
-        then finally from -1 to 1 with probability :math:`\epsilon`.
+        then finally from -1 to 1 with probability :math:`\epsilon_i`.
 
         Examples
         --------
@@ -446,7 +480,7 @@ class SIRState(DiscreteStateBase):
            <...>
            >>> plot(S, label="Susceptible")
            [...]
-           >>> plot(X, label="Infected")
+           >>> plot(X, label="Infectious")
            [...]
            >>> plot(R, label="Recovered")
            [...]
@@ -457,17 +491,12 @@ class SIRState(DiscreteStateBase):
            >>> legend(loc="best")
            <...>
            >>> tight_layout()
-           >>> savefig("SIR.pdf")
+           >>> savefig("SIR.svg")
 
-        .. testcode:: SIR
-           :hide:
-
-           savefig("SIR.svg")
-
-        .. figure:: SIR.*
+        .. figure:: SIR.svg
            :align: center
 
-           Number of susceptible, infected, and recovered nodes vs. time for an
+           Number of susceptible, infectious, and recovered nodes vs. time for an
            SIR dynamics.
 
         References
@@ -479,46 +508,55 @@ class SIRState(DiscreteStateBase):
            :doi:`10.1103/RevModPhys.87.925`, :arxiv:`1408.2701`
 
         """
-        EpidemicStateBase.__init__(self, g, v0, s)
-        DiscreteStateBase.__init__(self, g,
+        EpidemicStateBase.__init__(self, g, constant_beta,
                                    lib_dynamics.make_SEIR_state if exposed else lib_dynamics.make_SIR_state,
-                                   dict(beta=beta, gamma=gamma, r=r, epsilon=epsilon), self.s)
+                                   dict(beta=beta, gamma=gamma, r=r,
+                                        epsilon=epsilon),
+                                   v0, s)
+        DiscreteStateBase.__init__(self, g, self.make_state,
+                                   self.params, self.s)
 
 class SIRSState(DiscreteStateBase):
-    def __init__(self, g, beta=1, gamma=.1, mu=.1, r=0, exposed=False, epsilon=.1, v0=None, s=None):
+    def __init__(self, g, beta=1, gamma=.1, mu=.1, r=0, exposed=False,
+                 epsilon=.1, v0=None, s=None, constant_beta=True):
         r"""SIRS compartmental epidemic model.
 
         Parameters
         ----------
         g : :class:`~graph_tool.Graph`
            Graph to be used for the dynamics
-        beta : ``float`` (optional, default: ``1.``)
+        beta : ``float`` or :class:`~graph_tool.EdgePropertyMap` (optional, default: ``1.``)
            Transmission probability.
-        gamma : ``float`` (optional, default: ``.1``)
+        gamma : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            I to R recovery probability.
-        mu : ``float`` (optional, default: ``.1``)
+        mu : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            R to S recovery probability.
-        r : ``float`` (optional, default: ``0.``)
+        r : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``0.``)
            Spontaneous infection probability.
         exposed : ``boolean`` (optional, default: ``False``)
            If ``True``, an SEIRS model is simulated, with an additional "exposed"
            state.
-        epsilon : ``float`` (optional, default: ``.1``)
+        epsilon : ``float`` or :class:`~graph_tool.VertexPropertyMap` (optional, default: ``.1``)
            Susceptible to exposed transition probability. This only has an
            effect if ``exposed=True``.
         v0 : ``int`` or :class:`~graph_tool.Vertex` (optional, default: ``None``)
-           Initial infected vertex. If not provided, and if the global state is
+           Initial infectious vertex. If not provided, and if the global state is
            also not provided via paramter ``s``, a random vertex will be chosen.
         s : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
            Initial global state. If not provided, all vertices will be
            initialized to the susceptible state.
+        constant_beta : ``boolean`` (optional, default: ``True``)
+           If ``True``, and ``beta`` is an edge property map, it will be assumed
+           that the ``beta`` values do not change, such that the probability
+           values can be pre-computed for efficiency. If ``beta`` is a
+           ``float``, this option has no effect.
 
         Notes
         -----
 
         This implements an SIRS epidemic process
         [pastor-satorras-epidemic-2015]_, where nodes in the susceptible state
-        (value 0) are infected by neighbours in the infected state (value 1),
+        (value 0) are infected by neighbours in the infectious state (value 1),
         which can then eventually recover to a recovered state (value 2), and
         finally back to the susceptible state.
 
@@ -529,21 +567,21 @@ class SIRSState(DiscreteStateBase):
         1. If :math:`s_i(t) = 0`, we have :math:`s_i(t+1) = 1` with probability
             .. math::
 
-               (1-r)\left(1-\prod_j(1-\beta)^{A_{ij}\delta_{s_j(t),1}}\right) + r,
+               (1-r_i)\left[1-\prod_j(1-\beta_{ij})^{A_{ij}\delta_{s_j(t),1}}\right] + r_i,
 
            otherwise :math:`s_i(t+1) = 0`.
 
         2. If :math:`s_i(t) = 1`, we have :math:`s_i(t+1) = 2` with probability
-           :math:`\gamma`, or :math:`s_i(t+1) = 1` with probability
-           :math:`1-\gamma`.
+           :math:`\gamma_i`, or :math:`s_i(t+1) = 1` with probability
+           :math:`1-\gamma_i`.
 
         3. If :math:`s_i(t) = 2`, we have :math:`s_i(t+1) = 1` with probability
-           :math:`\mu`, or :math:`s_i(t+1) = 2` with probability
-           :math:`1-\mu`.
+           :math:`\mu_i`, or :math:`s_i(t+1) = 2` with probability
+           :math:`1-\mu_i`.
 
         If the option ``exposed == True`` is given, then the states transit
         first from 0 to -1 (exposed) with probability given by 1. above, and
-        then finally from -1 to 1 with probability :math:`\epsilon`.
+        then finally from -1 to 1 with probability :math:`\epsilon_i`.
 
         Examples
         --------
@@ -569,7 +607,7 @@ class SIRSState(DiscreteStateBase):
            <...>
            >>> plot(S, label="Susceptible")
            [...]
-           >>> plot(X, label="Infected")
+           >>> plot(X, label="Infectious")
            [...]
            >>> plot(R, label="Recovered")
            [...]
@@ -580,17 +618,12 @@ class SIRSState(DiscreteStateBase):
            >>> legend(loc="best")
            <...>
            >>> tight_layout()
-           >>> savefig("SIRS.pdf")
+           >>> savefig("SIRS.svg")
 
-        .. testcode:: SIRS
-           :hide:
-
-           savefig("SIRS.svg")
-
-        .. figure:: SIRS.*
+        .. figure:: SIRS.svg
            :align: center
 
-           Number of susceptible, infected, and recovered nodes vs. time for an
+           Number of susceptible, infectious, and recovered nodes vs. time for an
            SIRS dynamics.
 
         References
@@ -602,10 +635,13 @@ class SIRSState(DiscreteStateBase):
            :doi:`10.1103/RevModPhys.87.925`, :arxiv:`1408.2701`
 
         """
-        EpidemicStateBase.__init__(self, g, v0, s)
-        DiscreteStateBase.__init__(self, g,
+        EpidemicStateBase.__init__(self, g, constant_beta,
                                    lib_dynamics.make_SEIRS_state if exposed else lib_dynamics.make_SIRS_state,
-                                   dict(beta=beta, gamma=gamma, mu=mu, r=r, epsilon=epsilon), self.s)
+                                   dict(beta=beta, gamma=gamma, mu=mu, r=r,
+                                        epsilon=epsilon),
+                                   v0, s)
+        DiscreteStateBase.__init__(self, g, self.make_state,
+                                   self.params, self.s)
 
 
 class VoterState(DiscreteStateBase):
@@ -671,14 +707,9 @@ class VoterState(DiscreteStateBase):
            >>> legend(loc="best")
            <...>
            >>> tight_layout()
-           >>> savefig("voter.pdf")
+           >>> savefig("voter.svg")
 
-        .. testcode:: voter
-           :hide:
-
-           savefig("voter.svg")
-
-        .. figure:: voter.*
+        .. figure:: voter.svg
            :align: center
 
            Number of nodes with a given opinion vs. time for a voter model
@@ -764,14 +795,9 @@ class MajorityVoterState(DiscreteStateBase):
            >>> legend(loc="best")
            <...>
            >>> tight_layout()
-           >>> savefig("majority-voter.pdf")
+           >>> savefig("majority-voter.svg")
 
-        .. testcode:: majority-voter
-           :hide:
-
-           savefig("majority-voter.svg")
-
-        .. figure:: majority-voter.*
+        .. figure:: majority-voter.svg
            :align: center
 
            Number of nodes with a given opinion vs. time for a majority voter
@@ -839,24 +865,22 @@ class BinaryThresholdState(DiscreteStateBase):
 
         .. doctest:: binary-threshold
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.BinaryThresholdState(g, r=0.25)
            >>> ret = state.iterate_sync(niter=1000)
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-           ...               output_size=(700,400), output="binary-threshold.pdf")
+           ...               output="binary-threshold.pdf")
            <...>
 
-        .. testcode:: binary-threshold
-           :hide:
+        .. testcleanup:: binary-threshold
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
-                         edge_sloppy=True, vcmap=cm.bone,
-                         output_size=(700,400), output="binary-threshold.svg")
+           conv_png("binary-threshold.pdf")
 
-        .. figure:: binary-threshold.*
+        .. figure:: binary-threshold.png
            :align: center
+           :width: 80%
 
            State of a binary threshold dynamics on a political blog network.
         """
@@ -922,24 +946,22 @@ class IsingGlauberState(DiscreteStateBase):
 
         .. doctest:: glauber-ising
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.IsingGlauberState(g, beta=.05)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-           ...               output_size=(700,400), output="glauber-ising.pdf")
+           ...               output="glauber-ising.pdf")
            <...>
 
-        .. testcode:: glauber-ising
-           :hide:
+        .. testcleanup:: glauber-ising
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-                         edge_sloppy=True, output_size=(700,400),
-                         output="glauber-ising.svg")
+           conv_png("glauber-ising.pdf")
 
-        .. figure:: glauber-ising.*
+        .. figure:: glauber-ising.png
            :align: center
+           :width: 80%
 
            State of a Glauber Ising dynamics on a political blog network.
 
@@ -1010,24 +1032,22 @@ class CIsingGlauberState(DiscreteStateBase):
 
         .. doctest:: glauber-cising
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.CIsingGlauberState(g, beta=.2)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.magma,
-           ...               output_size=(700,400), output="glauber-cising.pdf")
+           ...               output="glauber-cising.pdf")
            <...>
 
-        .. testcode:: glauber-cising
-           :hide:
+        .. testcleanup:: glauber-cising
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.magma,
-                         edge_sloppy=True,
-                         output_size=(700,400), output="glauber-cising.svg")
+           conv_png("glauber-cising.pdf")
 
-        .. figure:: glauber-cising.*
+        .. figure:: glauber-cising.png
            :align: center
+           :width: 80%
 
            State of a continuous Glauber Ising dynamics on a political blog network.
 
@@ -1096,24 +1116,22 @@ class IsingMetropolisState(DiscreteStateBase):
 
         .. doctest:: metropolis-ising
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.IsingMetropolisState(g, beta=.1)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-           ...               output_size=(700,400), output="metropolis-ising.pdf")
+           ...               output="metropolis-ising.pdf")
            <...>
 
-        .. testcode:: metropolis-ising
-           :hide:
+        .. testcleanup:: metropolis-ising
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-                         edge_sloppy=True, output_size=(700,400),
-                         output="metropolis-ising.svg")
+           conv_png("metropolis-ising.pdf")
 
-        .. figure:: metropolis-ising.*
+        .. figure:: metropolis-ising.png
            :align: center
+           :width: 80%
 
            State of a Metropolis-Hastings Ising dynamics on a political blog network.
 
@@ -1190,25 +1208,23 @@ class PottsGlauberState(DiscreteStateBase):
 
         .. doctest:: glauber-potts
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> f = np.eye(4) * 0.1
            >>> state = gt.PottsGlauberState(g, f)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
-           ...               output_size=(700,400), output="glauber-potts.pdf")
+           ...               output="glauber-potts.pdf")
            <...>
 
-        .. testcode:: glauber-potts
-           :hide:
+        .. testcleanup:: glauber-potts
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
-                         edge_sloppy=True, output_size=(700,400),
-                         output="glauber-potts.svg")
+           conv_png("glauber-potts.pdf")
 
-        .. figure:: glauber-potts.*
+        .. figure:: glauber-potts.png
            :align: center
+           :width: 80%
 
            State of a Glauber Potts dynamics with :math:`q=4` on a political
            blog network.
@@ -1290,25 +1306,23 @@ class PottsMetropolisState(DiscreteStateBase):
 
         .. doctest:: metropolis-potts
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> f = np.eye(4) * 0.1
            >>> state = gt.PottsGlauberState(g, f)
            >>> ret = state.iterate_async(niter=1000 * g.num_vertices())
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
-           ...               output_size=(700,400), output="metropolis-potts.pdf")
+           ...               output="metropolis-potts.pdf")
            <...>
 
-        .. testcode:: metropolis-potts
-           :hide:
+        .. testcleanup:: metropolis-potts
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s,
-                         edge_sloppy=True, output_size=(700,400),
-                         output="metropolis-potts.svg")
+           conv_png("metropolis-potts.pdf")
 
-        .. figure:: metropolis-potts.*
+        .. figure:: metropolis-potts.png
            :align: center
+           :width: 80%
 
            State of a Metropolis-Hastings Potts dynamics with :math:`q=4` on a
            political blog network.
@@ -1395,24 +1409,22 @@ class KirmanState(DiscreteStateBase):
 
         .. doctest:: kirman
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.KirmanState(g)
            >>> ret = state.iterate_sync(niter=1000)
            >>> gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-           ...               output_size=(700,400), output="kirman.pdf")
+           ...               output="kirman.pdf")
            <...>
 
-        .. testcode:: kirman
-           :hide:
+        .. testcleanup:: kirman
 
-           gt.graph_draw(g, g.vp.pos, vertex_fill_color=state.s, vcmap=cm.bone,
-                         edge_sloppy=True, output_size=(700,400),
-                         output="kirman.svg")
+           conv_png("kirman.pdf")
 
-        .. figure:: kirman.*
+        .. figure:: kirman.png
            :align: center
+           :width: 80%
 
            State of Kirman's model on a political blog network.
 
@@ -1489,26 +1501,23 @@ class AxelrodState(DiscreteStateBase):
 
         .. doctest:: axelrod
 
-           >>> g = gt.GraphView(gt.collection.data["polblogs"], directed=False)
+           >>> g = gt.GraphView(gt.collection.data["polblogs"].copy(), directed=False)
            >>> gt.remove_parallel_edges(g)
            >>> g = gt.extract_largest_component(g, prune=True)
            >>> state = gt.AxelrodState(g, f=10, q=30, r=0.005)
            >>> ret = state.iterate_async(niter=10000000)
            >>> gt.graph_draw(g, g.vp.pos,
            ...               vertex_fill_color=gt.perfect_prop_hash([state.s])[0],
-           ...               vcmap=cm.magma, output_size=(700,400), output="axelrod.pdf")
+           ...               vcmap=cm.magma, output="axelrod.pdf")
            <...>
 
-        .. testcode:: axelrod
-           :hide:
+        .. testcleanup:: axelrod
 
-           gt.graph_draw(g, g.vp.pos,
-                         vertex_fill_color=gt.perfect_prop_hash([state.s])[0],
-                         edge_sloppy=True, vcmap=cm.magma, output_size=(700,400),
-                         output="axelrod.svg")
+           conv_png("axelrod.pdf")
 
-        .. figure:: axelrod.*
+        .. figure:: axelrod.png
            :align: center
+           :width: 80%
 
            State of Axelrod's model on a political blog network.
 
@@ -1734,17 +1743,12 @@ class KuramotoState(ContinuousStateBase):
            >>> ylabel(r"$\theta_i - \left<\theta\right>$")
            Text(...)
            >>> tight_layout()
-           >>> savefig("karate-kuramoto.pdf")
+           >>> savefig("karate-kuramoto.svg")
 
-        .. testcode:: kuramoto
-           :hide:
-
-           savefig("karate-kuramoto.svg")
-
-        .. figure:: karate-kuramoto.*
+        .. figure:: karate-kuramoto.svg
            :align: center
 
-           Kuramoto oscilator dynamics on the Karate Club network.
+           Kuramoto oscillator dynamics on the Karate Club network.
 
         References
         ----------
