@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.flow`` - Maximum flow algorithms
@@ -64,21 +64,19 @@ The following network will be used as an example throughout the documentation.
     gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(cap, mi=0, ma=3, power=1),
                   output="flow-example.pdf")
 
-.. testcode::
-   :hide:
+.. testcleanup::
 
-   gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(cap, mi=0, ma=3, power=1), output="flow-example.png")
+   conv_png("flow-example.pdf")
 
-.. figure:: flow-example.*
-    :align: center
+.. figure:: flow-example.png
+   :align: center
+   :width: 80%
 
-    Example network used in the documentation below. The edge capacities are
-    represented by the edge width.
+   Example network used in the documentation below. The edge capacities are
+   represented by the edge width.
 
 """
 
-from __future__ import division, absolute_import, print_function
-
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_flow")
 
@@ -145,17 +143,17 @@ def edmonds_karp_max_flow(g, source, target, capacity, residual=None):
     >>> gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=5, power=1), output="example-edmonds-karp.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=5, power=1), output="example-edmonds-karp.png")
+       conv_png("example-edmonds-karp.pdf")
 
-    .. figure:: example-edmonds-karp.*
-        :align: center
+    .. figure:: example-edmonds-karp.png
+       :align: center
+       :width: 80%
 
-        Edge flows obtained with the Edmonds-Karp algorithm. The source and
-        target are on the upper left and lower right corners, respectively. The
-        edge flows are represented by the edge width.
+       Edge flows obtained with the Edmonds-Karp algorithm. The source and
+       target are on the upper left and lower right corners, respectively. The
+       edge flows are represented by the edge width.
 
 
     References
@@ -226,18 +224,18 @@ def push_relabel_max_flow(g, source, target, capacity, residual=None):
     >>> gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=5, power=1), output="example-push-relabel.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=5, power=1), output="example-push-relabel.png")
+       conv_png("example-push-relabel.pdf")
 
-    .. figure:: example-push-relabel.*
-        :align: center
+    .. figure:: example-push-relabel.png
+       :align: center
+       :width: 80%
 
 
-        Edge flows obtained with the push-relabel algorithm. The source and
-        target are on the upper left and lower right corners, respectively. The
-        edge flows are represented by the edge width.
+       Edge flows obtained with the push-relabel algorithm. The source and
+       target are on the upper left and lower right corners, respectively. The
+       edge flows are represented by the edge width.
 
     References
     ----------
@@ -308,17 +306,17 @@ def boykov_kolmogorov_max_flow(g, source, target, capacity, residual=None):
     >>> gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=3, power=1), output="example-kolmogorov.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(res, mi=0, ma=3, power=1), output="example-kolmogorov.png")
+       conv_png("example-kolmogorov.pdf")
 
-    .. figure:: example-kolmogorov.*
-        :align: center
+    .. figure:: example-kolmogorov.png
+       :align: center
+       :width: 80%
 
-        Edge flows obtained with the Boykov-Kolmogorov algorithm. The source and
-        target are on the upper left and lower right corners, respectively. The
-        edge flows are represented by the edge width.
+       Edge flows obtained with the Boykov-Kolmogorov algorithm. The source and
+       target are on the upper left and lower right corners, respectively. The
+       edge flows are represented by the edge width.
 
     References
     ----------
@@ -394,20 +392,18 @@ def min_st_cut(g, source, capacity, residual):
     ...               vertex_font_size=18, edge_font_size=18, output="example-min-st-cut.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(cap, mi=3, ma=10, power=1),
-                     edge_text=res, vertex_fill_color=part, vertex_text=g.vertex_index,
-                     vertex_font_size=18, edge_font_size=18, output="example-min-st-cut.png")
+       conv_png("example-min-st-cut.pdf")
 
-    .. figure:: example-min-st-cut.*
-        :align: center
+    .. figure:: example-min-st-cut.png
+       :align: center
+       :width: 30%
 
-        Edge flows obtained with the Boykov-Kolmogorov algorithm. The source and
-        target are labeled ``0`` and ``7``, respectively. The edge capacities are
-        represented by the edge width, and the maximum flow by the edge labels.
-        Vertices of the same color are on the same side the minimum cut.
+       Edge flows obtained with the Boykov-Kolmogorov algorithm. The source and
+       target are labeled ``0`` and ``7``, respectively. The edge capacities are
+       represented by the edge width, and the maximum flow by the edge labels.
+       Vertices of the same color are on the same side the minimum cut.
 
     References
     ----------
@@ -469,17 +465,16 @@ def min_cut(g, weight):
     ...               output="example-min-cut.pdf")
     <...>
 
-    .. testcode::
-       :hide:
+    .. testcleanup::
 
-       gt.graph_draw(g, pos=pos, edge_pen_width=gt.prop_to_size(weight, mi=2, ma=8), vertex_fill_color=part,
-                     output="example-min-cut.png")
+       conv_png("example-min-cut.pdf")
 
-    .. figure:: example-min-cut.*
-        :align: center
+    .. figure:: example-min-cut.png
+       :align: center
+       :width: 30%
 
-        Vertices of the same color are on the same side of a minimum cut. The
-        edge weights are represented by the edge width.
+       Vertices of the same color are on the same side of a minimum cut. The
+       edge weights are represented by the edge width.
 
     References
     ----------
