@@ -3,44 +3,33 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
-
-from .. import _degree, _prop, Graph, GraphView, libcore, _get_rng, PropertyMap, \
-    conv_pickle_state
-import random
+from .. import _prop, Graph, GraphView, libcore, _get_rng
 from numpy import *
 import numpy
-from collections import defaultdict
-from scipy.special import gammaln
 import copy
 import warnings
 
-from .. import group_vector_property, ungroup_vector_property, Vector_size_t, \
-    perfect_prop_hash
+from .. import group_vector_property, ungroup_vector_property, perfect_prop_hash
 
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_inference as libinference")
 
 from .. generation import graph_union
-from .. stats import vertex_hist
 
 from . blockmodel import *
 from . blockmodel import _bm_test
@@ -92,19 +81,11 @@ class LayeredBlockState(OverlapBlockState, BlockState):
         be assumed, otherwise the traditional variant will be used.
     overlap : ``bool`` (optional, default: ``False``)
         If ``True``, the overlapping version of the model will be used.
-    allow_empty : ``bool`` (optional, default: ``True``)
-        If ``True``, partition description length computed will allow for empty
-        groups.
-    max_BE : ``int`` (optional, default: ``1000``)
-        If the number of blocks exceeds this value, a sparse matrix is used for
-        the block graph. Otherwise a dense matrix will be used.
-
     """
 
     def __init__(self, g, ec, eweight=None, vweight=None, recs=[], rec_types=[],
                  rec_params=[], b=None, B=None, clabel=None, pclabel=False,
-                 layers=False, deg_corr=True, overlap=False, allow_empty=False,
-                 **kwargs):
+                 layers=False, deg_corr=True, overlap=False, **kwargs):
 
         kwargs = kwargs.copy()
 
@@ -121,9 +102,9 @@ class LayeredBlockState(OverlapBlockState, BlockState):
             self.C = len(kwargs.get("gs"))
         self.layers = layers
 
-        if "max_BE" in kwargs:
-            del kwargs["max_BE"]
-        max_BE = 0
+        if "dense_bg" in kwargs:
+            del kwargs["dense_bg"]
+        dense_bg = False
 
         if vweight is None:
             vweight = g.new_vp("int", 1)
@@ -152,8 +133,8 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                    eweight=eweight, vweight=vweight, recs=recs,
                                    rec_types=rec_types, rec_params=rec_params,
                                    clabel=clabel, pclabel=pclabel,
-                                   deg_corr=deg_corr, allow_empty=allow_empty,
-                                   max_BE=max_BE, degs=tdegs,
+                                   deg_corr=deg_corr,
+                                   dense_bg=dense_bg, degs=tdegs,
                                    Lrecdx=self.Lrecdx[0],
                                    use_rmap=True,
                                    **dmask(kwargs, ["degs", "lweights", "gs"]))
@@ -164,7 +145,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                           rec_types=rec_types,
                                           rec_params=rec_params, clabel=clabel,
                                           pclabel=pclabel, deg_corr=deg_corr,
-                                          allow_empty=allow_empty, max_BE=max_BE,
+                                          dense_bg=dense_bg,
                                           Lrecdx=self.Lrecdx[0],
                                           **dmask(kwargs, ["degs", "lweights",
                                                            "gs", "bfield"]))
@@ -190,8 +171,6 @@ class LayeredBlockState(OverlapBlockState, BlockState):
         else:
             self.is_weighted = False
 
-        self.allow_empty = agg_state.allow_empty
-
         self.rec = agg_state.rec
         self.drec = agg_state.drec
         self.rec_types = agg_state.rec_types
@@ -273,7 +252,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
 
         self.layer_states = []
 
-        self.max_BE = max_BE
+        self.dense_bg = dense_bg
         self.bg = agg_state.bg
         self.wr = agg_state.wr
         self.mrs = agg_state.mrs
@@ -286,9 +265,10 @@ class LayeredBlockState(OverlapBlockState, BlockState):
         self.epsilon = agg_state.epsilon
         self._entropy_args = agg_state._entropy_args
         self.recdx = agg_state.recdx
-        if not self.overlap:
-            self.empty_blocks = agg_state.empty_blocks
-            self.empty_pos = agg_state.empty_pos
+        self.candidate_blocks = agg_state.candidate_blocks
+        self.candidate_pos = agg_state.candidate_pos
+        self.empty_blocks = agg_state.empty_blocks
+        self.empty_pos = agg_state.empty_pos
 
         self._coupled_state = None
 
@@ -375,8 +355,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                vweight=u.vp["weight"],
                                deg_corr=self.deg_corr,
                                degs=degs,
-                               allow_empty=self.allow_empty,
-                               max_BE=self.max_BE,
+                               dense_bg=self.dense_bg,
                                use_rmap=True)
         else:
             base_u, node_index = self.__get_base_u(u)
@@ -391,10 +370,9 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                       node_index=node_index,
                                       base_g=base_u,
                                       deg_corr=self.deg_corr,
-                                      max_BE=self.max_BE)
+                                      dense_bg=self.dense_bg)
         state.block_rmap = u.vp["brmap"]
         state.vmap = u.vp["vmap"]
-        state.free_blocks = Vector_size_t()
         return state
 
     def __getstate__(self):
@@ -412,12 +390,10 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                      clabel=self.clabel,
                      pclabel=self.pclabel,
                      bfield=self.bfield,
-                     deg_corr=self.deg_corr,
-                     allow_empty=self.allow_empty)
+                     deg_corr=self.deg_corr)
         return state
 
     def __setstate__(self, state):
-        conv_pickle_state(state)
         self.__init__(**state)
 
     def __copy__(self):
@@ -480,8 +456,6 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                   bfield=self.bfield if bfield is None else bfield,
                                   deg_corr=self.deg_corr if deg_corr is None else deg_corr,
                                   overlap=self.overlap if overlap is None else overlap,
-                                  allow_empty=kwargs.pop("allow_empty",
-                                                         self.allow_empty),
                                   layers=self.layers if layers is None else layers,
                                   base_g=self.base_g if self.overlap else None,
                                   half_edges=self.agg_state.half_edges if self.overlap else None,
@@ -498,8 +472,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
             state._couple_state(state.get_block_state(b=state.get_bclabel(),
                                                       copy_bg=False,
                                                       vweight="nonempty",
-                                                      Lrecdx=state.Lrecdx,
-                                                      allow_empty=False),
+                                                      Lrecdx=state.Lrecdx),
                                 self._coupled_state[1])
         return state
 
@@ -558,7 +531,6 @@ class LayeredBlockState(OverlapBlockState, BlockState):
         as the in the constructor.
         """
 
-
         copy_bg = kwargs.pop("copy_bg", True)
 
         if copy_bg:
@@ -682,9 +654,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                                   b=bg.vertex_index.copy("int") if b is None else b,
                                   deg_corr=deg_corr,
                                   overlap=overlap,
-                                  allow_empty=kwargs.pop("allow_empty",
-                                                         self.allow_empty),
-                                  max_BE=self.max_BE,
+                                  dense_bg=self.dense_bg,
                                   layers=self.layers if layers is None else layers,
                                   ec_done=True,
                                   degs=degs, lweights=lweights,
@@ -700,8 +670,7 @@ class LayeredBlockState(OverlapBlockState, BlockState):
             state._couple_state(state.get_block_state(b=state.get_bclabel(),
                                                       copy_bg=False,
                                                       vweight="nonempty",
-                                                      Lrecdx=state.Lrecdx,
-                                                      allow_empty=False),
+                                                      Lrecdx=state.Lrecdx),
                                 self._coupled_state[1])
 
         return state
@@ -858,7 +827,6 @@ class LayeredBlockState(OverlapBlockState, BlockState):
 
         Si = self.entropy(**dict(dict(partition_dl=False), **entropy_args))
 
-
         pos = {}
         nes = []
         for e in itertools.chain(missing, spurious):
@@ -883,24 +851,29 @@ class LayeredBlockState(OverlapBlockState, BlockState):
 
         try:
             new_es = []
-            for u, v, l in missing:
+            for i in range(len(missing)):
+                u, v, l = edge_list[i]
                 if not l[1]:
                     state = self.agg_state
                 else:
                     state = self.layer_states[l[0]]
                 e = state.g.add_edge(u, v)
-                if not l[1]:
+                if not l[1] and self.ec is not None:
                     self.ec[e] = l[0]
                 if state.is_weighted:
                     state.eweight[e] = 1
                 new_es.append((e, l))
 
             old_es = []
-            for u, v, l in spurious:
+            for i in range(len(spurious)):
+                u, v, l = edge_list[i + len(missing)]
                 if not l[1]:
                     state = self.agg_state
                     es = state.g.edge(u, v, all_edges=True)
-                    es = [e for e in es if self.ec[e] == l[0]]
+                    if self.ec is not None:
+                        es = [e for e in es if self.ec[e] == l[0]]
+                    else:
+                        es = list(es)
                     if len(es) > 0:
                         e = es[0]
                     else:
@@ -943,12 +916,12 @@ class LayeredBlockState(OverlapBlockState, BlockState):
                     if e is None:
                         e = state.g.add_edge(u, v)
                         state.eweight[e] = 0
-                        if not l[1]:
+                        if not l[1] and self.ec is not None:
                             self.ec[e] = l[0]
                     state.eweight[e] += 1
                 else:
                     e = state.g.add_edge(u, v)
-                    if not l[1]:
+                    if not l[1] and self.ec is not None:
                         self.ec[e] = l[0]
             self.add_vertex(pos.keys(), pos.values())
 
@@ -1137,4 +1110,4 @@ def init_layer_confined(g, ec):
     ba.fa = ba.fa + ec.fa * (ba.fa.max() + 1)
     continuous_map(ba)
     be = group_vector_property([ba, ba])
-    return be
\ No newline at end of file
+    return be
