@@ -3,25 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from .. import Vector_size_t, Vector_double
 
@@ -30,7 +25,7 @@ from . util import *
 from . nested_blockmodel import NestedBlockState
 
 def mcmc_equilibrate(state, wait=1000, nbreaks=2, max_niter=numpy.inf,
-                     force_niter=None, epsilon=0, gibbs=False, multiflip=False,
+                     force_niter=None, epsilon=0, gibbs=False, multiflip=True,
                      mcmc_args={}, entropy_args={}, history=False,
                      callback=None, verbose=False):
     r"""Equilibrate a MCMC with a given starting state.
@@ -55,7 +50,7 @@ def mcmc_equilibrate(state, wait=1000, nbreaks=2, max_niter=numpy.inf,
     gibbs : ``bool`` (optional, default: ``False``)
         If ``True``, each step will call ``state.gibbs_sweep`` instead of
         ``state.mcmc_sweep``.
-    multiflip : ``bool`` (optional, default: ``False``)
+    multiflip : ``bool`` (optional, default: ``True``)
         If ``True``, each step will call ``state.multiflip_mcmc_sweep`` instead of
         ``state.mcmc_sweep``.
     mcmc_args : ``dict`` (optional, default: ``{}``)
@@ -135,6 +130,8 @@ def mcmc_equilibrate(state, wait=1000, nbreaks=2, max_niter=numpy.inf,
         total_nattempts += nattempts
 
         if force_niter is not None:
+            max_S = max(S, max_S)
+            min_S = min(S, min_S)
             if niter >= force_niter:
                 break
         else:
@@ -263,7 +260,7 @@ def mcmc_anneal(state, beta_range=(1., 10.), niter=100, history=False,
             S = ret[0][-1]
         else:
             S = ret[0]
-            attempts += ret[1]
+            nattempts += ret[1]
             nmoves += ret[2]
 
         beta *= speed
@@ -342,6 +339,7 @@ def mcmc_multilevel(state, B, r=2, b_cache=None, anneal=False,
         raise ValueError("'mcmc_equilibrate_args' should be passed directly " +
                          "to mcmc_multilevel(), not via 'anneal_args'")
 
+    mcmc_equilibrate_args = dict(dict(multiflip=False), **mcmc_equilibrate_args)
     mcmc_args = mcmc_equilibrate_args.get("mcmc_args", {})
     if not mcmc_equilibrate_args.get("gibbs", False):
         mcmc_args["d"] = 0
@@ -390,8 +388,8 @@ class MulticanonicalState(object):
 
     Parameters
     ----------
-    g : :class:`~graph_tool.Graph`
-        Graph to be modelled.
+    state : :class:`~graph_tool.inference.blockmodel.BlockState` or :class:`~graph_tool.inference.overlap_blockmodel.OverlapBlockState` or :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState`
+        Block state to be used.
     S_min : ``float``
         Minimum energy.
     S_max : ``float``
@@ -400,9 +398,10 @@ class MulticanonicalState(object):
         Number of bins.
     """
 
-    def __init__(self, g, S_min, S_max, nbins=1000):
-        self._g = g
-        self._N = g.num_vertices()
+    def __init__(self, state, S_min, S_max, nbins=1000):
+        self._state = state
+        self._g = state.g
+        self._N = self._g.num_vertices()
         self._S_min = S_min
         self._S_max = S_max
         self._density = Vector_double()
@@ -413,18 +412,21 @@ class MulticanonicalState(object):
         self._f = None
 
     def __getstate__(self):
-        state = [self._g, self._S_min, self._S_max,
+        state = [self._state, self._S_min, self._S_max,
                  numpy.array(self._density.a), numpy.array(self._hist.a),
                  numpy.array(self._perm_hist), self._f]
         return state
 
     def __setstate__(self, state):
-        g, S_min, S_max, density, hist, phist, self._f = state
-        self.__init__(g, S_min, S_max, len(hist))
+        bstate, S_min, S_max, density, hist, phist, self._f = state
+        self.__init__(bstate, S_min, S_max, len(hist))
         self._density.a[:] = density
         self._hist.a[:] = hist
         self._perm_hist[:] = phist
 
+    def sweep(self, **kwargs):
+        self._state.multicanonical_sweep(self, **kwargs)
+
     def get_energies(self):
         "Get energy bounds."
         return self._S_min, self._S_max
@@ -507,7 +509,7 @@ class MulticanonicalState(object):
         self._perm_hist += self._hist.a
         self._hist.a = 0
 
-def multicanonical_equilibrate(state, m_state, f_range=(1., 1e-6), r=2,
+def multicanonical_equilibrate(m_state, f_range=(1., 1e-6), r=2,
                                flatness=.95, allow_gaps=True, callback=None,
                                multicanonical_args={}, verbose=False):
     r"""Equilibrate a multicanonical Monte Carlo sampling using the Wang-Landau
@@ -515,8 +517,6 @@ def multicanonical_equilibrate(state, m_state, f_range=(1., 1e-6), r=2,
 
     Parameters
     ----------
-    state : Any state class (e.g. :class:`~graph_tool.inference.blockmodel.BlockState`)
-        Initial state. This state will be modified during the algorithm.
     m_state :  :class:`~graph_tool.inference.mcmc.MulticanonicalState`
         Initial multicanonical state, where the state density will be stored.
     f_range : ``tuple`` of two floats (optional, default: ``(1., 1e-6)``)
@@ -565,7 +565,7 @@ def multicanonical_equilibrate(state, m_state, f_range=(1., 1e-6), r=2,
     if m_state._f is None:
         m_state._f = f_range[0]
     while m_state._f >= f_range[1]:
-        state.multicanonical_sweep(m_state, **multicanonical_args)
+        m_state.sweep(**multicanonical_args)
         hf = m_state.get_flatness(allow_gaps=allow_gaps)
 
         if callback is not None:
@@ -575,8 +575,8 @@ def multicanonical_equilibrate(state, m_state, f_range=(1., 1e-6), r=2,
             print(verbose_pad(verbose) +
                   "count: %d  f: %#8.8g  flatness: %#8.8g  nonempty bins: %d  S: %#8.8g  B: %d" % \
                   (count, m_state._f, hf, (m_state._hist.a > 0).sum(),
-                   state.entropy(**multicanonical_args.get("entropy_args", {})),
-                   state.get_nonempty_B()))
+                   m_state._state.entropy(**multicanonical_args.get("entropy_args", {})),
+                   m_state._state.get_nonempty_B()))
 
         if hf > flatness:
             m_state._f /= r
@@ -611,6 +611,8 @@ class TemperingState(object):
         if idx is None:
             self.idx = list(range(len(betas)))
         self.beta_dl = beta_dl
+        self.swap_attempts = 0
+        self.swaps = numpy.zeros(len(states), dtype="int")
 
     def entropy(self, **kwargs):
         """Returns the sum of the entropy of the parallel states. All keyword
@@ -636,7 +638,7 @@ class TemperingState(object):
             return [s.entropy(**kwargs) * beta for s, beta in
                     zip(self.states, self.betas)]
 
-    def states_swap(self, adjacent=True, **kwargs):
+    def states_swap(self,  **kwargs):
         """Perform a full sweep of the parallel states, where swaps are attempted. All
         relevant keyword arguments are propagated to the individual states'
         `entropy()` method."""
@@ -644,20 +646,13 @@ class TemperingState(object):
         verbose = kwargs.get("verbose", False)
         eargs = kwargs.get("entropy_args", {})
 
-        if adjacent:
-            idx = numpy.arange(len(self.states) - 1)
-        else:
-            idx = numpy.arange(len(self.states))
+        self.swap_attempts += 1
+        idx = numpy.arange(len(self.states) - 1)
         numpy.random.shuffle(idx)
         nswaps = 0
         dS = 0
         for i in idx:
-            if adjacent:
-                j = i + 1
-            else:
-                j = i
-                while j == i:
-                    j = numpy.random.randint(0, len(idx))
+            j = i + 1
 
             s1 = self.states[i]
             s2 = self.states[j]
@@ -671,11 +666,13 @@ class TemperingState(object):
                 P1_b = -s1.entropy(beta_dl=b1, **eargs)
                 P2_b = -s2.entropy(beta_dl=b2, **eargs)
             else:
-                P1_f = -s1.entropy(**eargs) * b2
-                P2_f = -s2.entropy(**eargs) * b1
+                S1 = s1.entropy(**eargs)
+                S2 = s2.entropy(**eargs)
+                P1_f = -S1 * b2
+                P2_f = -S2 * b1
 
-                P1_b = -s1.entropy(**eargs) * b1
-                P2_b = -s2.entropy(**eargs) * b2
+                P1_b = -S1 * b1
+                P2_b = -S2 * b2
 
             ddS = -(P1_f + P2_f - P1_b - P2_b)
 
@@ -683,6 +680,7 @@ class TemperingState(object):
                 self.states[j], self.states[i], self.idx[j], self.idx[i] = \
                             self.states[i], self.states[j], self.idx[i], self.idx[j]
                 nswaps += 1
+                self.swaps[i] += 1
                 dS += ddS
                 if check_verbose(verbose):
                     print(verbose_pad(verbose)
@@ -728,7 +726,7 @@ class TemperingState(object):
     def mcmc_sweep(self, **kwargs):
         """Perform a full mcmc sweep of the parallel states, where swap or moves are
         chosen randomly. It accepts an keyword argument ``r`` (default: ``0.1``)
-        specifying the relative probability with which state swaps is performed
+        specifying the relative probability with which state swaps are performed
         with respect to node moves.  All remaining keyword arguments are
         propagated to the individual states' `mcmc_sweep()` method.
         """
@@ -739,7 +737,7 @@ class TemperingState(object):
     def multiflip_mcmc_sweep(self, **kwargs):
         """Perform a full mcmc sweep of the parallel states, where swap or moves are
         chosen randomly. It accepts an keyword argument ``r`` (default: ``0.1``)
-        specifying the relative probability with which state swaps is performed
+        specifying the relative probability with which state swaps are performed
         with respect to node moves.  All remaining keyword arguments are
         propagated to the individual states' `mcmc_sweep()` method.
         """
@@ -750,7 +748,7 @@ class TemperingState(object):
     def gibbs_sweep(self, **kwargs):
         """Perform a full Gibbs mcmc sweep of the parallel states, where swap or moves
         are chosen randomly. It accepts an keyword argument ``r`` (default:
-        ``0.1``) specifying the relative probability with which state swaps is
+        ``0.1``) specifying the relative probability with which state swaps are
         performed with respect to node moves.  All remaining keyword arguments
         are propagated to the individual states' `gibbs_sweep()` method.
         """
