@@ -3,25 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import numpy
 from . util import *
@@ -119,7 +114,7 @@ def minimize_blockmodel_dl(g, B_min=None, B_max=None, b_min=None, b_max=None,
                            mcmc_args={}, anneal_args={},
                            mcmc_equilibrate_args={}, shrink_args={},
                            mcmc_multilevel_args={}, verbose=False):
-    """Fit the stochastic block model, by minimizing its description length using an
+    r"""Fit the stochastic block model, by minimizing its description length using an
     agglomerative heuristic.
 
     Parameters
@@ -198,14 +193,9 @@ def minimize_blockmodel_dl(g, B_min=None, B_max=None, b_min=None, b_max=None,
        >>> g = gt.collection.data["polbooks"]
        >>> state = gt.minimize_blockmodel_dl(g)
        >>> state.draw(pos=g.vp["pos"], vertex_shape=state.get_blocks(),
-       ...            output="polbooks_blocks_mdl.pdf")
+       ...            output="polbooks_blocks_mdl.svg")
        <...>
 
-    .. testcleanup:: mdl
-
-       state.draw(pos=g.vp["pos"], vertex_shape=state.get_blocks(),
-                  output="polbooks_blocks_mdl.png")
-
     .. figure:: polbooks_blocks_mdl.*
        :align: center
 
@@ -223,13 +213,9 @@ def minimize_blockmodel_dl(g, B_min=None, B_max=None, b_min=None, b_max=None,
 
        >>> g = gt.collection.data["polbooks"]
        >>> state = gt.minimize_blockmodel_dl(g, overlap=True)
-       >>> state.draw(pos=g.vp["pos"], output="polbooks_overlap_blocks_mdl.pdf")
+       >>> state.draw(pos=g.vp["pos"], output="polbooks_overlap_blocks_mdl.svg")
        <...>
 
-    .. testcleanup:: mdl_overlap
-
-       state.draw(pos=g.vp["pos"], output="polbooks_overlap_blocks_mdl.png")
-
     .. figure:: polbooks_overlap_blocks_mdl.*
        :align: center
 
@@ -240,34 +226,9 @@ def minimize_blockmodel_dl(g, B_min=None, B_max=None, b_min=None, b_max=None,
 
     References
     ----------
-    .. [holland-stochastic-1983] Paul W. Holland, Kathryn Blackmond Laskey,
-       Samuel Leinhardt, "Stochastic blockmodels: First steps",
-       Carnegie-Mellon University, Pittsburgh, PA 15213, U.S.A.,
-       :doi:`10.1016/0378-8733(83)90021-7`.
-    .. [faust-blockmodels-1992] Katherine Faust, and Stanley
-       Wasserman. "Blockmodels: Interpretation and Evaluation." Social Networks
-       14, no. 1-2 (1992): 5-61, :doi:`10.1016/0378-8733(92)90013-W`.
-    .. [karrer-stochastic-2011] Brian Karrer, and M. E. J. Newman. "Stochastic
-       Blockmodels and Community Structure in Networks." Physical Review E 83,
-       no. 1 (2011): 016107, :doi:`10.1103/PhysRevE.83.016107`.
-    .. [peixoto-entropy-2012] Tiago P. Peixoto "Entropy of Stochastic Blockmodel
-       Ensembles." Physical Review E 85, no. 5 (2012): 056122,
-       :doi:`10.1103/PhysRevE.85.056122`, :arxiv:`1112.6028`.
-    .. [peixoto-parsimonious-2013] Tiago P. Peixoto, "Parsimonious module
-       inference in large networks", Phys. Rev. Lett. 110, 148701 (2013),
-       :doi:`10.1103/PhysRevLett.110.148701`, :arxiv:`1212.4794`.
     .. [peixoto-efficient-2014] Tiago P. Peixoto, "Efficient Monte Carlo and greedy
        heuristic for the inference of stochastic block models", Phys. Rev. E 89,
        012804 (2014), :doi:`10.1103/PhysRevE.89.012804`, :arxiv:`1310.4378`.
-    .. [peixoto-model-2016] Tiago P. Peixoto, "Model selection and hypothesis
-       testing for large-scale network models with overlapping groups",
-       Phys. Rev. X 5, 011033 (2016), :doi:`10.1103/PhysRevX.5.011033`,
-       :arxiv:`1409.3059`.
-    .. [peixoto-inferring-2016] Tiago P. Peixoto, "Inferring the mesoscale
-       structure of layered, edge-valued and time-varying networks",
-       Phys. Rev. E 92, 042807 (2015), :doi:`10.1103/PhysRevE.92.042807`,
-       :arXiv:`1504.02381`.
-
     """
 
     b_cache = {} # keep a global cache
@@ -320,7 +281,7 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
                                   mcmc_args={}, anneal_args={},
                                   mcmc_equilibrate_args={}, shrink_args={},
                                   mcmc_multilevel_args={}, verbose=False):
-    """Fit the nested stochastic block model, by minimizing its description length
+    r"""Fit the nested stochastic block model, by minimizing its description length
     using an agglomerative heuristic.
 
     Parameters
@@ -408,10 +369,11 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
 
     .. testcleanup:: nested_mdl
 
-       state.draw(output="power_nested_mdl.png")
+       conv_png("power_nested_mdl.pdf")
 
-    .. figure:: power_nested_mdl.*
+    .. figure:: power_nested_mdl.png
        :align: center
+       :width: 60%
 
        Hierarchical Block partition of a power-grid network, which minimizes
        the description length of the network according to the nested
@@ -427,10 +389,11 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
 
     .. testcleanup:: nested_mdl_overlap
 
-       state.draw(output="celegans_nested_mdl_overlap.png")
+       conv_png("celegans_nested_mdl_overlap.pdf")
 
-    .. figure:: celegans_nested_mdl_overlap.*
+    .. figure:: celegans_nested_mdl_overlap.png
        :align: center
+       :width: 60%
 
        Overlapping block partition of the *C. elegans* neural network, which
        minimizes the description length of the network according to the nested
@@ -438,24 +401,10 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
 
     References
     ----------
-
     .. [peixoto-hierarchical-2014] Tiago P. Peixoto, "Hierarchical block
        structures and high-resolution model selection in large networks ",
        Phys. Rev. X 4, 011047 (2014), :doi:`10.1103/PhysRevX.4.011047`,
        :arxiv:`1310.4377`.
-    .. [peixoto-efficient-2014] Tiago P. Peixoto, "Efficient Monte Carlo and
-       greedy heuristic for the inference of stochastic block models",
-       Phys. Rev. E 89, 012804 (2014), :doi:`10.1103/PhysRevE.89.012804`,
-       :arxiv:`1310.4378`.
-    .. [peixoto-model-2016] Tiago P. Peixoto, "Model selection and hypothesis
-       testing for large-scale network models with overlapping groups",
-       Phys. Rev. X 5, 011033 (2016), :doi:`10.1103/PhysRevX.5.011033`,
-       :arxiv:`1409.3059`.
-    .. [peixoto-inferring-2016] Tiago P. Peixoto, "Inferring the mesoscale
-       structure of layered, edge-valued and time-varying networks",
-       Phys. Rev. E 92, 042807 (2015), :doi:`10.1103/PhysRevE.92.042807`,
-       :arXiv:`1504.02381`.
-
     """
 
     mcmc_multilevel_args = \
@@ -512,6 +461,7 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
     state = NestedBlockState(g, bs=bs,
                              base_type=State,
                              deg_corr=deg_corr,
+                             sampling=False,
                              **dmask(state_args, ["deg_corr"]))
 
     bisection_args = dict(dict(mcmc_multilevel_args=mcmc_multilevel_args,
@@ -524,4 +474,4 @@ def minimize_nested_blockmodel_dl(g, B_min=None, B_max=None, b_min=None,
                        **dmask(hierarchy_minimize_args,
                                ["B_max", "B_min", "bisection_args", "verbose"]))
 
-    return state
\ No newline at end of file
+    return state
