@@ -3,27 +3,22 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
-
-from .. import _degree, _prop, Graph, GraphView, conv_pickle_state
+from .. import _prop, Graph, GraphView
 from . blockmodel import *
 from . blockmodel import _bm_test
 from . overlap_blockmodel import *
@@ -40,8 +35,9 @@ class NestedBlockState(object):
     ----------
     g : :class:`~graph_tool.Graph`
         Graph to be modeled.
-    bs : ``list`` of :class:`~graph_tool.VertexPropertyMap` or :class:`numpy.ndarray`
-        Hierarchical node partition.
+    bs : ``list`` of :class:`~graph_tool.VertexPropertyMap` or :class:`numpy.ndarray` (optional, default: ``None``)
+        Hierarchical node partition. If not provided it will correspond to a
+        single-group hierarchy of length :math:`\lceil\log_2(N)\rceil`.
     base_type : ``type`` (optional, default: :class:`~graph_tool.inference.blockmodel.BlockState`)
         State type for lowermost level
         (e.g. :class:`~graph_tool.inference.blockmodel.BlockState`,
@@ -53,7 +49,7 @@ class NestedBlockState(object):
     hentropy_args : ``dict`` (optional, default: `{}`)
         Keyword arguments to be passed to the ``entropy()`` method of the
         higher-level states.
-    sampling : ``bool`` (optional, default: ``False``)
+    sampling : ``bool`` (optional, default: ``True``)
         If ``True``, the state will be properly prepared for MCMC sampling (as
         opposed to minimization).
     state_args : ``dict`` (optional, default: ``{}``)
@@ -61,11 +57,20 @@ class NestedBlockState(object):
     **kwargs :  keyword arguments
         Keyword arguments to be passed to base type constructor. The
         ``state_args`` parameter overrides this.
+
     """
 
-    def __init__(self, g, bs, base_type=BlockState, state_args={},
-                 hstate_args={}, hentropy_args={}, sampling=False, **kwargs):
+    def __init__(self, g, bs=None, base_type=BlockState, state_args={},
+                 hstate_args={}, hentropy_args={}, sampling=True, **kwargs):
         self.g = g
+
+        if bs is None:
+            if base_type is OverlapBlockState or state_args.get("overlap", False):
+                b = zeros(2 * g.num_vertices(), dtype="int")
+            else:
+                b = zeros(g.num_vertices(), dtype="int")
+            bs = [b] + [zeros(1, dtype="int")] * int(ceil(log2(len(b))))
+
         self.base_type = base_type
         if base_type is LayeredBlockState:
             self.Lrecdx = []
@@ -77,8 +82,7 @@ class NestedBlockState(object):
             recs = self.state_args.get("recs", None)
             if recs is not None:
                 self.state_args["rec_params"] = ["microcanonical"] * len(recs)
-        self.hstate_args = dict(dict(deg_corr=False, vweight="nonempty",
-                                     allow_empty=False),
+        self.hstate_args = dict(dict(deg_corr=False, vweight="nonempty"),
                                 **hstate_args)
         self.hstate_args["Lrecdx"] = self.Lrecdx
         self.sampling = sampling
@@ -204,17 +208,22 @@ class NestedBlockState(object):
         return state
 
     def __setstate__(self, state):
-        conv_pickle_state(state)
-        if "kwargs" in state: # backwards compatibility
-            state["state_args"] = state["kwargs"]
-            del  state["kwargs"]
         self.__init__(**state)
 
     def get_bs(self):
         """Get hierarchy levels as a list of :class:`numpy.ndarray` objects with the
         group memberships at each level.
         """
-        return [s.b.fa for s in self.levels]
+        return [s.b.fa.copy() for s in self.levels]
+
+    def get_state(self):
+        """Alias to :meth:`~NestedBlockState.get_bs`."""
+        return self.get_bs()
+
+    def set_state(self, bs):
+        r"""Sets the internal nested partition of the state."""
+        for i in range(len(bs)):
+            self.levels[i].set_state(bs[i])
 
     def get_levels(self):
         """Get hierarchy levels as a list of :class:`~graph_tool.inference.blockmodel.BlockState`
@@ -771,10 +780,8 @@ class NestedBlockState(object):
     def _h_sweep_states(self, algo, **kwargs):
         entropy_args = kwargs.get("entropy_args", {})
         for l, lstate, args in self._h_sweep_gen(**kwargs):
-            if l > 0 and "beta_dl" in entropy_args:
-                yield l, lstate, algo(self.levels[l], dispatch=False, **args), entropy_args["beta_dl"]
-            else:
-                yield l, lstate, algo(self.levels[l], dispatch=False, **args), 1
+            beta_dl = entropy_args.get("beta_dl", 1) if l > 0 else 1
+            yield l, lstate, algo(self.levels[l], dispatch=False, **args), beta_dl
 
     def _h_sweep_parallel_dispatch(states, sweeps, algo):
         ret = None
@@ -803,11 +810,19 @@ class NestedBlockState(object):
         ``c * 2 ** l`` for ``l`` in the range ``[0, L-1]``. Optionally, a list
         of values may be passed instead, which specifies the value of ``c[l]``
         to be used at each level.
+
+        .. warning::
+
+           This function performs ``niter`` sweeps at each hierarchical level
+           once. This means that in order for the chain to equilibrate, we need
+           to call this function several times, i.e. it is not enough to call
+           it once with a large value of ``niter``.
+
         """
 
         c = kwargs.pop("c", 1)
         if not isinstance(c, collections.Iterable):
-            c = [c] + [c * 2 ** l for l in range(1, len(self.levels))]
+            c = [c * 2 ** l for l in range(0, len(self.levels))]
 
         if kwargs.pop("dispatch", True):
             if _bm_test():
@@ -844,11 +859,21 @@ class NestedBlockState(object):
         of values may be passed instead, which specifies the value of ``c[l]``
         to be used at each level.
 
+        .. warning::
+
+           This function performs ``niter`` sweeps at each hierarchical level
+           once. This means that in order for the chain to equilibrate, we need
+           to call this function several times, i.e. it is not enough to call
+           it once with a large value of ``niter``.
+
         """
 
+        psingle = kwargs.get("psingle", self.g.num_vertices())
+        kwargs["psingle"] = psingle
+
         c = kwargs.pop("c", 1)
         if not isinstance(c, collections.Iterable):
-            c = [c] + [c * 2 ** l for l in range(1, len(self.levels))]
+            c = [c * 2 ** l for l in range(0, len(self.levels))]
 
         if kwargs.pop("dispatch", True):
             if _bm_test():
@@ -872,6 +897,40 @@ class NestedBlockState(object):
         algo = lambda s, lstates, lsweep_states: s._multiflip_mcmc_sweep_parallel_dispatch(lstates, lsweep_states)
         return NestedBlockState._h_sweep_parallel_dispatch(states, sweeps, algo)
 
+    def gibbs_sweep(self, **kwargs):
+        r"""Perform ``niter`` sweeps of a rejection-free Gibbs sampling MCMC
+        to sample network partitions.
+
+        The arguments accepted are the same as in
+        :meth:`graph_tool.inference.blockmodel.BlockState.gibbs_sweep`.
+
+        .. warning::
+
+           This function performs ``niter`` sweeps at each hierarchical level
+           once. This means that in order for the chain to equilibrate, we need
+           to call this function several times, i.e. it is not enough to call
+           it once with a large value of ``niter``.
+
+        """
+        if _bm_test():
+            kwargs = dict(kwargs, test=False)
+            entropy_args = kwargs.get("entropy_args", {})
+            Si = self.entropy(**entropy_args)
+
+        dS, nattempts, nmoves = self._h_sweep(lambda s, **a: s.gibbs_sweep(**a),
+                                              **kwargs)
+
+        if _bm_test():
+            Sf = self.entropy(**entropy_args)
+            assert math.isclose(dS, (Sf - Si), abs_tol=1e-8), \
+                "inconsistent entropy delta %g (%g): %s" % (dS, Sf - Si,
+                                                            str(entropy_args))
+        return dS, nattempts, nmoves
+
+    def _gibbs_sweep_parallel_dispatch(states, sweeps):
+        algo = lambda s, lstates, lsweep_states: s._gibbs_sweep_parallel_dispatch(lstates, lsweep_states)
+        return NestedBlockState._h_sweep_parallel_dispatch(states, sweeps, algo)
+
     def multicanonical_sweep(self, **kwargs):
         r"""Perform ``niter`` sweeps of a non-Markovian multicanonical sampling using the
         Wang-Landau algorithm.
@@ -931,7 +990,7 @@ class NestedBlockState(object):
 def hierarchy_minimize(state, B_min=None, B_max=None, b_min=None, b_max=None,
                        frozen_levels=None, bisection_args={},
                        epsilon=1e-8, verbose=False):
-    """Attempt to find a fit of the nested stochastic block model that minimizes the
+    r"""Attempt to find a fit of the nested stochastic block model that minimizes the
     description length.
 
     Parameters
@@ -1152,7 +1211,7 @@ def hierarchy_minimize(state, B_min=None, B_max=None, b_min=None, b_max=None,
         if state.levels[-1].B > 1:
             bstate = state.levels[-1].get_block_state(**dict(state.hstate_args,
                                                              b=zeros(state.levels[-1].B),
-                                                             Lrecdx=levels[-1].Lrecdx))
+                                                             Lrecdx=state.levels[-1].Lrecdx))
             state.levels.append(bstate)
             state._regen_Lrecdx()
 
@@ -1270,8 +1329,12 @@ def get_hierarchy_tree(state, empty_branches=True):
 
         last_pos = pos
         g = s
-        if g.num_vertices() == 1:
-            break
+        if empty_branches:
+            if g.num_vertices() == 1:
+                break
+        else:
+            if g.vp.count.fa.sum() == 1:
+                break
         b = g.vp["b"]
 
     if not empty_branches:
