@@ -3,33 +3,26 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
-
-from .. import _degree, _prop, Graph, GraphView, libcore, _get_rng, PropertyMap, \
-    conv_pickle_state
+from .. import _prop, Graph, libcore, _get_rng, PropertyMap
 
 import random
 from numpy import *
 import numpy
-from collections import defaultdict
 
 from .. import group_vector_property, ungroup_vector_property
 
@@ -75,18 +68,14 @@ class OverlapBlockState(BlockState):
     deg_corr : ``bool`` (optional, default: ``True``)
         If ``True``, the degree-corrected version of the blockmodel ensemble will
         be assumed, otherwise the traditional variant will be used.
-    allow_empty : ``bool`` (optional, default: ``False``)
-        If ``True``, partition description length computed will allow for empty
-        groups.
-    max_BE : ``int`` (optional, default: ``1000``)
-        If the number of blocks exceeds this number, a sparse representation of
-        the block graph is used, which is slightly less efficient, but uses less
-        memory,
+    dense_bg : ``bool`` (optional, default: ``False``)
+        If ``True`` a dense matrix is used for the block graph, otherwise a
+        sparse matrix will be used.
     """
 
     def __init__(self, g, b=None, B=None, recs=[], rec_types=[], rec_params=[],
-                 clabel=None, pclabel=None, deg_corr=True, allow_empty=False,
-                 max_BE=1000, **kwargs):
+                 clabel=None, pclabel=None, deg_corr=True, dense_bg=False,
+                 **kwargs):
 
         kwargs = kwargs.copy()
 
@@ -103,6 +92,9 @@ class OverlapBlockState(BlockState):
         if node_index is not None and self.base_g is None:
             raise ValueError("Must specify base graph if node_index is specified...")
 
+        if B is None and b is None:
+            B = 1
+
         # create overlapping structure
         if node_index is None:
             # keep base graph
@@ -212,7 +204,9 @@ class OverlapBlockState(BlockState):
         self.B = B
 
         self.candidate_blocks = Vector_size_t()
-        self.candidate_blocks.extend(arange(self.B, dtype="int"))
+        self.candidate_pos = self.bg.new_vp("int")
+        self.empty_blocks = Vector_size_t()
+        self.empty_pos = self.bg.new_vp("int")
 
         if pclabel is not None:
             if isinstance(pclabel, PropertyMap):
@@ -252,11 +246,11 @@ class OverlapBlockState(BlockState):
                 if numpy.any(idx):
                     self.epsilon[i] = abs(self.rec[i].a[idx]).min() / 10
 
-        self.max_BE = max_BE
+        self.dense_bg = dense_bg
+        self.use_hash = not self.dense_bg
 
-        self.use_hash = self.B > self.max_BE
-
-        self.allow_empty = True
+        self.bfield = self.g.new_vp("vector<double>")
+        self.Bfield = Vector_double()
 
         self._abg = self.bg._get_any()
         self._state = libinference.make_overlap_block_state(self, _get_rng())
@@ -281,8 +275,6 @@ class OverlapBlockState(BlockState):
         if eweight != "unity":
             kwargs["eweight"] = eweight
 
-        self.ignore_degrees = kwargs.pop("ignore_degrees", self.g.new_vp("bool"))
-
         if len(kwargs) > 0:
             warnings.warn("unrecognized keyword arguments: " +
                           str(list(kwargs.keys())))
@@ -328,22 +320,19 @@ class OverlapBlockState(BlockState):
                                   half_edges=kwargs.get("half_edges", self.half_edges),
                                   node_index=kwargs.get("node_index", self.node_index),
                                   eindex=kwargs.get("eindex", self.eindex),
-                                  max_BE=kwargs.get("max_BE", self.max_BE),
+                                  dense_bg=kwargs.get("dense_bg", self.dense_bg),
                                   base_g=kwargs.get("base_g", self.base_g),
                                   Lrecdx=kwargs.pop("Lrecdx", self.Lrecdx.copy()),
                                   epsilon=kwargs.pop("epsilon",
                                                      self.epsilon.copy()),
-                                  allow_empty=kwargs.pop("allow_empty",
-                                                         self.allow_empty),
                                   **dmask(kwargs, ["half_edges", "node_index",
                                                    "eindex", "base_g", "drec",
-                                                   "max_BE"]))
+                                                   "dense_bg"]))
         if self._coupled_state is not None:
             state._couple_state(state.get_block_state(b=state.get_bclabel(),
                                                       vweight="nonempty",
                                                       copy_bg=False,
-                                                      Lrecdx=state.Lrecdx,
-                                                      allow_empty=False),
+                                                      Lrecdx=state.Lrecdx),
                                 self._coupled_state[1])
         return state
 
@@ -360,12 +349,11 @@ class OverlapBlockState(BlockState):
                      half_edges=self.half_edges,
                      node_index=self.node_index,
                      eindex=self.eindex,
-                     max_BE=self.max_BE,
+                     dense_bg=self.dense_bg,
                      base_g=self.base_g)
         return state
 
     def __setstate__(self, state):
-        conv_pickle_state(state)
         self.__init__(**state)
 
     def get_E(self):
