@@ -3,28 +3,23 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
-
-from .. import _degree, _prop, Graph, GraphView, libcore, _get_rng, \
-    PropertyMap, edge_endpoint_property
+from .. import _prop, Graph, GraphView, _get_rng, PropertyMap, \
+    edge_endpoint_property
 
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_inference as libinference")
@@ -50,6 +45,7 @@ class UncertainBaseState(object):
 
         self.g = g
 
+        state_args = dict(state_args)
         if bstate is None:
             if init_empty:
                 self.u = Graph(directed=g.is_directed())
@@ -63,11 +59,19 @@ class UncertainBaseState(object):
                 self.u = g.copy()
                 self.eweight = self.u.new_ep("int", val=1)
         else:
-            self.u = bstate.g
+            self.u = bstate.g.copy()
             if nested:
                 self.eweight = bstate.levels[0].eweight
             else:
                 self.eweight = bstate.eweight
+            self.eweight = self.u.own_property(self.eweight.copy())
+            if nested:
+                bstate = bstate.copy(g=self.u,
+                                     state_args=dict(bstate.state_args,
+                                                     eweight=self.eweight))
+            else:
+                bstate = bstate.copy(g=self.u, eweight=self.eweight)
+
         self.u.set_fast_edge_removal()
 
         self.self_loops = self_loops
@@ -87,11 +91,8 @@ class UncertainBaseState(object):
 
         if bstate is None:
             if nested:
-                state_args["state_args"] = state_args.get("state_args", {})
-                state_args["state_args"]["eweight"] = self.eweight
-                state_args["sampling"] = True
-                self.nbstate = NestedBlockState(self.u, **dict(state_args,
-                                                               sampling=True))
+                state_args["eweight"] = self.eweight
+                self.nbstate = NestedBlockState(self.u, state_args=state_args)
                 self.bstate = self.nbstate.levels[0]
             else:
                 self.nbstate = None
@@ -114,6 +115,14 @@ class UncertainBaseState(object):
 
         init_q_cache()
 
+    def __getstate__(self):
+        return dict(g=self.g, nested=self.nbstate is not None,
+                    bstate=(self.nbstate if self.nbstate is not None else self.bstate),
+                    self_loops=self.self_loops)
+
+    def __setstate__(self, state):
+        self.__init__(**state)
+
     def get_block_state(self):
         """Return the underlying block state, which can be either
         :class:`~graph_tool.inference.blockmodel.BlockState` or
@@ -155,6 +164,11 @@ class UncertainBaseState(object):
         entropy_args = get_uentropy_args(dentropy_args)
         return self._state.add_edge_dS(int(u), int(v), entropy_args)
 
+    def set_state(self, g, w):
+        if w.value_type() != "int32_t":
+            w = w.copy("int32_t")
+        self._state.set_state(g._Graph__graph, w._get_any())
+
     def _algo_sweep(self, algo, r=.5, **kwargs):
         kwargs = kwargs.copy()
         beta = kwargs.get("beta", 1.)
@@ -223,13 +237,13 @@ class UncertainBaseState(object):
         return self.mcmc_sweep(multiflip=True, **kwargs)
 
     def get_edge_prob(self, u, v, entropy_args={}, epsilon=1e-8):
-        r"""Return conditional posterior probability of edge :math:`(u,v)`."""
+        r"""Return conditional posterior log-probability of edge :math:`(u,v)`."""
         entropy_args = dict(self.bstate._entropy_args, **entropy_args)
         ea = get_uentropy_args(entropy_args)
         return self._state.get_edge_prob(u, v, ea, epsilon)
 
     def get_edges_prob(self, elist, entropy_args={}, epsilon=1e-8):
-        r"""Return conditional posterior probability of an edge list, with
+        r"""Return conditional posterior log-probability of an edge list, with
         shape :math:`(E,2)`."""
         entropy_args = dict(self.bstate._entropy_args, **entropy_args)
         ea = get_uentropy_args(entropy_args)
@@ -294,6 +308,49 @@ class UncertainBaseState(object):
         g.ep.eprob.fa /= g.gp.count
         return g
 
+    def collect_marginal_multigraph(self, g=None):
+        r"""Collect marginal latent multigraph during MCMC runs.
+
+        Parameters
+        ----------
+        g : :class:`~graph_tool.Graph` (optional, default: ``None``)
+            Previous marginal multigraph.
+
+        Returns
+        -------
+        g : :class:`~graph_tool.Graph`
+            New marginal graph, with internal edge
+            :class:`~graph_tool.EdgePropertyMap` ``"w"`` and ``"wcount"``,
+            containing the edge multiplicities and their respective counts.
+
+        Notes
+        -----
+
+        The mean posterior marginal multiplicity distribution of a multi-edge
+        :math:`(i,j)` is defined as
+
+        .. math::
+
+           \pi_{ij}(w) = \sum_{\boldsymbol G}\delta_{w,G_{ij}}P(\boldsymbol G|\boldsymbol D)
+
+        where :math:`P(\boldsymbol G|\boldsymbol D)` is the posterior
+        probability of a multigraph :math:`\boldsymbol G` given the data.
+
+        """
+
+        if g is None:
+            g = Graph(directed=self.g.is_directed())
+            g.add_vertex(self.g.num_vertices())
+            g.ep.w = g.new_ep("vector<int>")
+            g.ep.wcount = g.new_ep("vector<int>")
+
+        libinference.collect_marginal_count(g._Graph__graph,
+                                            self.u._Graph__graph,
+                                            _prop("e", self.u, self.eweight),
+                                            _prop("e", g, g.ep.w),
+                                            _prop("e", g, g.ep.wcount))
+        return g
+
 class UncertainBlockState(UncertainBaseState):
     r"""Inference state of an uncertain graph, using the stochastic block model as a
     prior.
@@ -365,13 +422,9 @@ class UncertainBlockState(UncertainBaseState):
         self._state = libinference.make_uncertain_state(self.bstate._state,
                                                         self)
     def __getstate__(self):
-        return dict(g=self.g, q=self._q, q_default=self._q_default,
-                    aE=self.aE, nested=self.nbstate is not None,
-                    bstate=(self.nbstate.copy() if self.nbstate is not None else
-                            self.bstate.copy()), self_loops=self.self_loops)
-
-    def __setstate__(self, state):
-        self.__init__(**state)
+        state = super(UncertainBlockState, self).__getstate__()
+        return dict(state,  q=self._q, q_default=self._q_default,
+                    aE=self.aE)
 
     def copy(self, **kwargs):
         """Return a copy of the state."""
@@ -390,6 +443,84 @@ class UncertainBlockState(UncertainBaseState):
                                                  self._state,
                                                  _get_rng())
 
+class LatentMultigraphBlockState(UncertainBaseState):
+    r"""Inference state of an erased Poisson multigraph, using the stochastic
+    block model as a prior.
+
+    Parameters
+    ----------
+    g : :class:`~graph_tool.Graph`
+        Measured graph.
+    aE : ``float`` (optional, default: ``NaN``)
+        Expected total number of edges used in prior. If ``NaN``, a flat
+        prior will be used instead.
+    nested : ``boolean`` (optional, default: ``True``)
+        If ``True``, a :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState`
+        will be used, otherwise
+        :class:`~graph_tool.inference.blockmodel.BlockState`.
+    state_args : ``dict`` (optional, default: ``{}``)
+        Arguments to be passed to
+        :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` or
+        :class:`~graph_tool.inference.blockmodel.BlockState`.
+    bstate : :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` or :class:`~graph_tool.inference.blockmodel.BlockState`  (optional, default: ``None``)
+        If passed, this will be used to initialize the block state
+        directly.
+    self_loops : bool (optional, default: ``False``)
+        If ``True``, it is assumed that the uncertain graph can contain
+        self-loops.
+
+    References
+    ----------
+    .. [peixoto-latent-2020] Tiago P. Peixoto, "Latent Poisson models for
+       networks with heterogeneous density", :arxiv:`2002.07803`
+    """
+
+    def __init__(self, g, aE=numpy.nan, nested=True, state_args={},
+                 bstate=None, self_loops=False, **kwargs):
+
+        super(LatentMultigraphBlockState, self).__init__(g, nested=nested,
+                                                         state_args=state_args,
+                                                         bstate=bstate,
+                                                         self_loops=self_loops,
+                                                         **kwargs)
+
+        self.q = self.g.new_ep("double", val=numpy.inf)
+        self.q_default = -numpy.inf
+        self.S_const = 0
+
+        self.aE = aE
+        if numpy.isnan(aE):
+            self.E_prior = False
+        else:
+            self.E_prior = True
+
+        self._state = libinference.make_uncertain_state(self.bstate._state,
+                                                        self)
+    def __getstate__(self):
+        state = super(LatentMultigraphBlockState, self).__getstate__()
+        return dict(state, aE=self.aE)
+
+    def __setstate__(self, state):
+        self.__init__(**state)
+
+    def copy(self, **kwargs):
+        """Return a copy of the state."""
+        return LatentMultigraphBlockState(**dict(self.__getstate__(), **kwargs))
+
+    def __copy__(self):
+        return self.copy()
+
+    def __repr__(self):
+        return "<LatentMultigraphBlockState object with %s, at 0x%x>" % \
+            (self.nbstate if self.nbstate is not None else self.bstate,
+             id(self))
+
+    def _mcmc_sweep(self, mcmc_state):
+        mcmc_state.edges_only = True
+        return libinference.mcmc_uncertain_sweep(mcmc_state,
+                                                 self._state,
+                                                 _get_rng())
+
 class MeasuredBlockState(UncertainBaseState):
     r"""Inference state of a measured graph, using the stochastic block model as a
     prior.
@@ -406,7 +537,7 @@ class MeasuredBlockState(UncertainBaseState):
         positive measurements for each edge.
     n_default : ``int`` (optional, default: ``1``)
         Total number of measurements for each non-edge.
-    x_default : ``int`` (optional, default: ``1``)
+    x_default : ``int`` (optional, default: ``0``)
         Total number of positive measurements for each non-edge.
     fn_params : ``dict`` (optional, default: ``dict(alpha=1, beta=1)``)
         Beta distribution hyperparameters for the probability of missing
@@ -467,16 +598,11 @@ class MeasuredBlockState(UncertainBaseState):
                                                        self)
 
     def __getstate__(self):
-        return dict(g=self.g, n=self.n, x=self.x, n_default=self.n_default,
+        state = super(MeasuredBlockState, self).__getstate__()
+        return dict(state, n=self.n, x=self.x, n_default=self.n_default,
                     x_default=self.x_default,
                     fn_params=dict(alpha=self.alpha, beta=self.beta),
-                    fp_params=dict(mu=self.mu, nu=self.nu), aE=self.aE,
-                    nested=self.nbstate is not None,
-                    bstate=(self.nbstate if self.nbstate is not None
-                            else self.bstate), self_loops=self.self_loops)
-
-    def __setstate__(self, state):
-        self.__init__(**state)
+                    fp_params=dict(mu=self.mu, nu=self.nu), aE=self.aE)
 
     def copy(self, **kwargs):
         """Return a copy of the state."""
@@ -622,16 +748,11 @@ class MixedMeasuredBlockState(UncertainBaseState):
         self.sync_q()
 
     def __getstate__(self):
-        return dict(g=self.g, n=self.n, x=self.x, n_default=self.n_default,
+        state = super(MixedMeasuredBlockState, self).__getstate__()
+        return dict(state, n=self.n, x=self.x, n_default=self.n_default,
                     x_default=self.x_default,
                     fn_params=dict(alpha=self.alpha, beta=self.beta),
-                    fp_params=dict(mu=self.mu, nu=self.nu), aE=self.aE,
-                    nested=self.nbstate is not None,
-                    bstate=(self.nbstate if self.nbstate is not None
-                            else self.bstate), self_loops=self.self_loops)
-
-    def __setstate__(self, state):
-        self.__init__(**state)
+                    fp_params=dict(mu=self.mu, nu=self.nu), aE=self.aE)
 
     def copy(self, **kwargs):
         """Return a copy of the state."""
@@ -752,15 +873,10 @@ class DynamicsBlockStateBase(UncertainBaseState):
         self._state.set_params(self.params)
 
     def __getstate__(self):
-        return dict(g=self.g, s=self.s, t=self.t, x=self.x, aE=self.aE,
-                    nested=self.nbstate is not None,
-                    bstate=(self.nbstate.copy() if self.nbstate is not None else
-                            self.bstate.copy()), self_loops=self.self_loops,
+        state = super(DynamicsBlockState, self).__getstate__()
+        return dict(state, s=self.s, t=self.t, x=self.x, aE=self.aE,
                     **self.params)
 
-    def __setstate__(self, state):
-        self.__init__(**state)
-
     def copy(self, **kwargs):
         """Return a copy of the state."""
         return type(self)(**dict(self.__getstate__(), **kwargs))
@@ -836,7 +952,7 @@ class DynamicsBlockStateBase(UncertainBaseState):
         return self.x
 
     def get_edge_prob(self, u, v, x, entropy_args={}, epsilon=1e-8):
-        r"""Return conditional posterior probability of edge :math:`(u,v)`."""
+        r"""Return conditional posterior log-probability of edge :math:`(u,v)`."""
         entropy_args = dict(self.bstate._entropy_args, **entropy_args)
         ea = get_uentropy_args(entropy_args)
         return self._state.get_edge_prob(u, v, x, ea, epsilon)
@@ -971,8 +1087,8 @@ class EpidemicsBlockState(DynamicsBlockStateBase):
         References
         ----------
         .. [peixoto-network-2019] Tiago P. Peixoto, "Network reconstruction and
-           community detection from dynamics", :arxiv:`1903.10833`
-
+           community detection from dynamics", Phys. Rev. Lett. 123 128301
+           (2019), :doi:`10.1103/PhysRevLett.123.128301`, :arxiv:`1903.10833`
         """
 
         if beta is None:
@@ -1114,7 +1230,7 @@ class IsingBaseBlockState(DynamicsBlockStateBase):
                  has_zero=False, **kwargs):
         r"""Base state for network reconstruction based on the Ising model, using the
         stochastic block model as a prior. This class is not supposed to be
-        instantiated directly. Instead one of it's specialized subclasses must
+        instantiated directly. Instead one of its specialized subclasses must
         be used, which have the same signature: :class:`IsingGlauberBlockState`,
         :class:`PseudoIsingBlockState`, :class:`CIsingGlauberBlockState`,
         :class:`PseudoCIsingBlockState`.
@@ -1173,7 +1289,8 @@ class IsingBaseBlockState(DynamicsBlockStateBase):
         References
         ----------
         .. [peixoto-network-2019] Tiago P. Peixoto, "Network reconstruction and
-           community detection from dynamics", :arxiv:`1903.10833`
+           community detection from dynamics", Phys. Rev. Lett. 123 128301
+           (2019), :doi:`10.1103/PhysRevLett.123.128301`, :arxiv:`1903.10833`
 
         """
 
@@ -1356,3 +1473,79 @@ class PseudoCIsingBlockState(IsingBaseBlockState):
     def _mcmc_sweep_h(self, mcmc_state):
         return libinference.mcmc_pseudo_cising_sweep_h(mcmc_state, self._state,
                                                        _get_rng())
+
+
+def marginal_multigraph_entropy(g, ecount):
+    r"""Compute the entropy of the marginal latent multigraph distribution.
+
+    Parameters
+    ----------
+    g : :class:`~graph_tool.Graph`
+        Marginal multigraph.
+    ecount : :class:`~graph_tool.EdgePropertyMap`
+        Vector-valued edge property map containing the counts of edge
+        multiplicities.
+
+    Returns
+    -------
+    eh : :class:`~graph_tool.EdgePropertyMap`
+        Marginal entropy of edge multiplicities.
+
+    Notes
+    -----
+
+    The mean posterior marginal multiplicity distribution of a multi-edge
+    :math:`(i,j)` is defined as
+
+    .. math::
+
+       \pi_{ij}(w) = \sum_{\boldsymbol G}\delta_{w,G_{ij}}P(\boldsymbol G|\boldsymbol D)
+
+    where :math:`P(\boldsymbol G|\boldsymbol D)` is the posterior
+    probability of a multigraph :math:`\boldsymbol G` given the data.
+
+    The corresponding entropy is therefore given (in nats) by
+
+    .. math::
+
+       \mathcal{S}_{ij} = -\sum_w\pi_{ij}(w)\ln \pi_{ij}(w).
+
+    """
+
+    eh = g.new_ep("double")
+    libinference.marginal_count_entropy(g._Graph__graph,
+                                        _prop("e", g, ecount),
+                                        _prop("e", g, eh))
+    return eh
+
+def marginal_multigraph_sample(g, ews, ecount):
+
+    w = g.new_ep("int")
+    libinference.marginal_multigraph_sample(g._Graph__graph,
+                                                _prop("e", g, ews),
+                                                _prop("e", g, ecount),
+                                                _prop("e", g, w),
+                                                _get_rng())
+    return w
+
+def marginal_multigraph_lprob(g, ews, ecount, ew):
+
+    L = libinference.marginal_multigraph_lprob(g._Graph__graph,
+                                               _prop("e", g, ews),
+                                               _prop("e", g, ecount),
+                                               _prop("e", g, ew))
+    return L
+
+def marginal_graph_sample(g, ep):
+    w = g.new_ep("int")
+    libinference.marginal_graph_sample(g._Graph__graph,
+                                       _prop("e", g, ep),
+                                       _prop("e", g, w),
+                                       _get_rng())
+    return w
+
+def marginal_graph_lprob(g, ep, w):
+    L = libinference.marginal_graph_lprob(g._Graph__graph,
+                                          _prop("e", g, ep),
+                                          _prop("e", g, w))
+    return L
