@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.search`` - Search algorithms
@@ -62,16 +62,9 @@ In this module, most documentation examples will make use of the network
 >>> pos = g.vp["pos"]
 >>> gt.graph_draw(g, pos, vertex_text=name, vertex_font_size=12, vertex_shape="double_circle",
 ...               vertex_fill_color="#729fcf", vertex_pen_width=3,
-...               edge_pen_width=weight, output="search_example.pdf")
+...               edge_pen_width=weight, output="search_example.svg")
 <...>
 
-.. testcode::
-   :hide:
-
-   gt.graph_draw(g, pos=pos, vertex_text=name, vertex_font_size=12, vertex_shape="double_circle",
-                 vertex_fill_color="#729fcf", vertex_pen_width=3,
-                 edge_pen_width=weight, output="search_example.png")
-
 .. figure:: search_example.*
    :alt: search example
    :align: center
@@ -84,16 +77,10 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-import sys
-if sys.version_info < (3,):
-    range = xrange
-
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_search")
 
 from .. import _prop, _python_type, _get_null_vertex
-import weakref
 import numpy
 
 __all__ = ["bfs_search", "bfs_iterator", "BFSVisitor", "dfs_search",
@@ -1643,16 +1630,9 @@ def astar_search(g, source, weight, visitor=AStarVisitor(),
     ...     v = p
     >>> gt.graph_draw(g, pos=pos, output_size=(300, 300), vertex_fill_color=touch_v,
     ...               vcmap=matplotlib.cm.binary, edge_color=ecolor,
-    ...               edge_pen_width=ewidth, output="astar-delaunay.pdf")
+    ...               edge_pen_width=ewidth, output="astar-delaunay.svg")
     <...>
 
-    .. testcode::
-       :hide:
-
-       gt.graph_draw(g, pos=pos, output_size=(300, 300), vertex_fill_color=touch_v,
-                     vcmap=matplotlib.cm.binary, edge_color=ecolor,
-                     edge_pen_width=ewidth, output="astar-delaunay.png")
-
     .. figure:: astar-delaunay.*
        :align: center
 
@@ -1762,15 +1742,7 @@ def astar_search(g, source, weight, visitor=AStarVisitor(),
     ...     v = p
     >>> vcolor[v] = "black"
     >>> pos = gt.graph_draw(g, output_size=(300, 300), vertex_fill_color=vcolor, edge_color=ecolor,
-    ...                     edge_pen_width=ewidth, output="astar-implicit.pdf")
-
-    .. testcode::
-       :hide:
-
-       gt.graph_draw(g, pos=pos, output_size=(300, 300), vertex_fill_color=vcolor,
-                     edge_color=ecolor, edge_pen_width=ewidth,
-                     output="astar-implicit.png")
-
+    ...                     edge_pen_width=ewidth, output="astar-implicit.svg")
 
     .. figure:: astar-implicit.*
        :align: center
