@@ -3,20 +3,20 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2019 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation; either version 3 of the License, or (at your option) any
+# later version.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
 ``graph_tool.spectral`` - Spectral properties
@@ -39,8 +39,6 @@ Contents
 ++++++++
 """
 
-from __future__ import division, absolute_import, print_function
-
 from .. import _degree, _prop, Graph, GraphView, _limit_args, Vector_int64_t, \
     Vector_double
 from .. stats import label_self_loops
@@ -132,12 +130,7 @@ def adjacency(g, weight=None, index=None):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("adjacency-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("adjacency-spectrum.svg")
+    >>> savefig("adjacency-spectrum.svg")
 
     .. figure:: adjacency-spectrum.*
         :align: center
@@ -258,12 +251,7 @@ def laplacian(g, deg="total", normalized=False, weight=None, index=None):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("laplacian-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("laplacian-spectrum.svg")
+    >>> savefig("laplacian-spectrum.svg")
 
     .. figure:: laplacian-spectrum.*
         :align: center
@@ -282,12 +270,7 @@ def laplacian(g, deg="total", normalized=False, weight=None, index=None):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("norm-laplacian-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("norm-laplacian-spectrum.svg")
+    >>> savefig("norm-laplacian-spectrum.svg")
 
     .. figure:: norm-laplacian-spectrum.*
         :align: center
@@ -486,12 +469,7 @@ def transition(g, weight=None, index=None):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("transition-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("transition-spectrum.svg")
+    >>> savefig("transition-spectrum.svg")
 
     .. figure:: transition-spectrum.*
         :align: center
@@ -583,12 +561,7 @@ def modularity_matrix(g, weight=None, index=None):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("modularity-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("modularity-spectrum.svg")
+    >>> savefig("modularity-spectrum.svg")
 
     .. figure:: modularity-spectrum.*
         :align: center
@@ -653,7 +626,7 @@ def hashimoto(g, index=None, compact=False):
 
     Notes
     -----
-    The Hashimoto (a.k.a. non-backtracking) matrix is defined as
+    The Hashimoto (a.k.a. non-backtracking) matrix [hashimoto]_ is defined as
 
     .. math::
 
@@ -680,7 +653,7 @@ def hashimoto(g, index=None, compact=False):
         \end{array}\right)
 
     where :math:`\boldsymbol A` is the adjacency matrix, and :math:`\boldsymbol
-    D` is the diagonal matrix with the node degrees.
+    D` is the diagonal matrix with the node degrees [krzakala_spectral]_.
 
     Examples
     --------
@@ -701,12 +674,7 @@ def hashimoto(g, index=None, compact=False):
     >>> ylabel(r"$\operatorname{Im}(\lambda)$")
     Text(...)
     >>> tight_layout()
-    >>> savefig("hashimoto-spectrum.pdf")
-
-    .. testcode::
-       :hide:
-
-       savefig("hashimoto-spectrum.svg")
+    >>> savefig("hashimoto-spectrum.svg")
 
     .. figure:: hashimoto-spectrum.*
         :align: center
